OC.L10N.register(
    "spreed",
    {
    "a conversation" : "對話",
    "(Duration %s)" : "（歷時 %s）",
    "You attended a call with {user1}" : "您加入了與 {user1} 的通話",
    "_%n guest_::_%n guests_" : ["%n位訪客"],
    "You attended a call with {user1} and {user2}" : "您加入了與 {user1} 及 {user2} 之間的通話",
    "You attended a call with {user1}, {user2} and {user3}" : "您加入了與 {user1}﹑{user2} 及 {user3} 之間的通話",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "您加入了與 {user1}﹑{user2}﹑{user3} 及 {user4} 之間的通話",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "您加入了與 {user1}﹑{user2}﹑{user3}﹑{user4} 及 {user5} 之間的通話",
    "_%n other_::_%n others_" : ["及另外%n位其他人"],
    "{actor} invited you to {call}" : "{actor} 邀請你加入 {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "你被邀請加入<strong>對話</strong>或<strong>通話</strong>",
    "Other activities" : "其它活動",
    "Talk" : "Talk",
    "Guest" : "訪客",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## 歡迎來到Nextcloud Talk!\n在此對話中，我們將向您介紹Nextcloud Talk中可用的新功能。",
    "## New in Talk %s" : "## Talk 的新功能 %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- 現在可以使用Microsoft Edge和Safari參加音頻和視像通話",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- 單對單對話現在是持久的，不會再意外話地變成小組對話。同樣，當參與者之一離開對話時，該對話不再自動刪除。僅當兩個參與者都離開時，對話才會從伺服器中刪除",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- 您現在可以通過在聊天室中張貼“@all”來通知所有參與者",
    "- With the \"arrow-up\" key you can repost your last message" : "- 使用【上箭頭】鍵，您可以重新發佈上一條消息",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk 現在支持指令。發送 “/help” 作為聊天訊息，以查看管理員是否配置了任何指令。",
    "- With projects you can create quick links between conversations, files and other items" : "- 使用方案，您可以在對話﹑檔案和其他項目之間建立快速連結",
    "- You can now mention guests in the chat" : "- 您現在可以在聊天中提及來賓",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- 對話現在可以有一個等候室。這將使主持人可以加入聊天及通話以準備會議，而用戶和來賓則必須等待",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- 您現在可以直接回覆郵件，為其他用戶提供更多有關您的郵件內容的背景訊息",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- 現在，搜尋對話和參與者也將過濾您現有的對話，從而使找出以前的對話變得更加容易",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- 現在，您可以在安裝社交圈子應用程式後將自訂用戶群組添加到對話中",
    "- Check out the new grid and call view" : "- 體驗新的網格和通話視圖",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- 您現在可以直接從裝置上載檔案或將檔案拖放到聊天中",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- 現在可以使用查看器應用程式直接在聊天視圖中打開分享檔案",
    "- You can now search for chats and messages in the unified search in the top bar" : "您現在可以搜索聊天和訊息在頂部欄的搜索",
    "- Spice up your messages with emojis from the emoji picker" : "使用表情符號選擇器中的表情符號來豐富您的訊息",
    "- You can now change your camera and microphone while being in a call" : "您可以在通話時更改相機和麥克風 ",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- 給您的對話一些描述的上下文並打開它，以便已登入的用戶可以找到它並加入",
    "- See a read status and send failed messages again" : "- 查看讀取狀態並再次發送失敗的訊息",
    "- Raise your hand in a call with the R key" : "- 使用【R】鍵在通話中舉手",
    "- Join the same conversation and call from multiple devices" : "- 加入同一個對話並從多個設備撥打電話",
    "- Send voice messages, share your location or contact details" : "- 發送音頻信息，分享您的位置或聯絡方式",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- 將群組添加到對話中，新群組成員將自動成為參與者",
    "- A preview of your audio and video is shown before joining a call" : "- 在加入通話之前顯示您的音頻和視頻預覽",
    "- You can now blur your background in the newly designed call view" : "- 您現在可以在新設計的通話視圖中模糊背景",
    "- Moderators can now assign general and individual permissions to participants" : "- 版主現在可以為參與者分配一般和個人權限",
    "- You can now react to chat messages" : "- 您現在可以對聊天訊息做出反應",
    "- In the sidebar you can now find an overview of the latest shared items" : "- 現在您可以在側邊欄中找到最新共享項目的概覽",
    "- Use a poll to collect the opinions of others or settle on a date" : "- 使用民意調查收集他人的意見或確定日期",
    "- Configure an expiration time for chat messages" : "- 配置聊天訊息的過期時間",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- 在不通知他人的情況下開始通話。通話開始後，您可以發送單獨的通話通知。",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- 在不緊急的情況下發送聊天訊息而不通知收件人",
    "- Emojis can now be autocompleted by typing a \":\"" : "- 表情符號現在可以通過輸入 \"：\" 自動完成",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- 通過輸入 \"/\" 使用新的智能選擇器鏈接各種項目",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- 主持人現在可以創建分組討論室（需要高性能後端系統）",
    "- Calls can now be recorded (requires the High-performance backend)" : "- 現在可以記錄通話（需要高性能後端系統）",
    "- Conversations can now have an avatar or emoji as icon" : "- 對話現在可以有虛擬化身或 emoji 作為圖示",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- 除了視頻通話中的模糊背景外，現在還可以使用虛擬背景",
    "- Reactions are now available during calls" : "- 現在可以在通話期間做出反應",
    "- Typing indicators show which users are currently typing a message" : "- 打字指示器顯示目前正在打字的用戶",
    "- Groups can now be mentioned in chats" : "- 現在可以在聊天中提及群組",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- 如果註冊了轉錄提供商應用程式，通話錄音會自動轉錄",
    "- Chat messages can be translated if a translation provider app is registered" : "- 如果註冊了翻譯提供商應用程式，則可以翻譯聊天消息",
    "- **Markdown** can now be used in _chat_ messages" : "- 現在可以在 _聊天_ 訊息中使用 **Markdown** 了",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhook 現在可用於實作機器人。要取得更多資訊，請參閱文件 https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- 在聊天訊息上設定提醒，如此稍後可收到通知",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- 使用**給自己的筆記 **對話來記筆記並在裝置間分享資訊",
    "- Captions allow to send a message with a file at the same time" : "- 字幕允許同時傳送包含檔案的訊息",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- 現在在分享螢幕時可以看到講者的視訊，通話反應以動畫形式顯示",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- 登入的作者和主持人現在可以在 6 小時內編輯訊息",
    "- Unsent message drafts are now saved in your browser" : "- 未發送的訊息草稿現在保存在您的瀏覽器中",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- 文字聊天現在可以透過聯盟方式與其他 Talk 伺服器通訊",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- 主持人現在可以禁止帳戶和訪客，以防止他們重新加入對話",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- 連結的日曆活動和外出替換的即將打來的電話現在顯示在對話中",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- 通話現在可以透過聯盟方式與其他 Talk 伺服器通訊（需要高效能後端）",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- 介紹 Nextcloud Talk 桌面客戶端，支持 Windows、macOS 和 Linux：%s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- 使用 Nextcloud Assistant 總結通話錄音和聊天中的未讀消息。",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- 改進會議功能，識別通過電郵地址邀請的嘉賓，導入參與者名單，草擬投票並下載通話參與者名單。",
    "- Archive conversations to stay focused" : "- 存檔對話以保持專注",
    "- Schedule a meeting into your calendar from within a conversation" : "- 在對話中安排會議到您的日曆",
    "- Search for messages of the current conversation directly in the right sidebar" : "- 直接在右側邊欄搜尋目前對話的訊息",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- 使用新的精簡清單（在 Talk 設定中啟用），第一眼就能看到更多對話內容",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- 會議對話現在會從日曆同步標題和描述，並且在開始前會用搜尋過濾器隱藏。",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- 在通知設定中標記對話為敏感，以隱藏對話清單和通知中的訊息內容。",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- 在「勿擾」模式下接收推送通知，請將對話標記為重要。",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- 在一對一通話中添加其他參與者，即可隨時創建新的群組通話",
    "- Use threads to keep your chat and discussions organized" : "- 使用討論串來讓您的聊天與討論井然有序",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- 通話期間現已提供即時轉錄功能（需安裝即時轉錄 ExApp 及高效能後端系統）",
    "- Moderators can now pin messages so they are kept at the top" : "- 主持人現在可以將訊息釘選，讓它們固定顯示在最上方",
    "- Schedule a message to send it at a later time" : "- 安排訊息於稍後傳送",
    "_All %n participant_::_All %n participants_" : ["所有 %n 個參與者"],
    "Talk updates ✅" : "Talk 更新 ✅",
    "Reaction deleted by author" : "反應被作者刪除",
    "{actor} created the conversation" : "{actor} 建立了對話",
    "You created the conversation" : "你建立了對話",
    "System created the conversation" : "系統創建了對話",
    "An administrator created the conversation" : "管理員建立了對話",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} 將對話從 “%1$s” 重命名為 “%2$s”",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "您將對話從 “%1$s” 重命名為 “%2$s”",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "管理員將對話從 “%1$s” 重命名為 “%2$s”",
    "{actor} set the description" : "{actor} 設置了描述",
    "You set the description" : "您設置了描述",
    "An administrator set the description" : "管理員設置了描述",
    "{actor} removed the description" : "{actor} 刪除了描述",
    "You removed the description" : "您刪除了描述",
    "An administrator removed the description" : "管理員刪除了描述",
    "You started a silent call" : "您發起了無聲通話",
    "Outgoing silent call" : "無聲去電",
    "{actor} started a silent call" : "{actor} 發起了無聲通話",
    "Incoming silent call" : "無聲來電",
    "You started a call" : "您發起了一通話",
    "Outgoing call" : "去電",
    "{actor} started a call" : "{actor} 發起了一通話",
    "Incoming call" : "來電",
    "{actor} joined the call" : "{actor} 加入了通話",
    "You joined the call" : "您已加入了通話",
    "{actor} left the call" : "{actor} 離開了通話",
    "You left the call" : "你離開了通話",
    "{actor} unlocked the conversation" : "{actor} 解鎖了對話",
    "You unlocked the conversation" : "您解鎖了對話",
    "An administrator unlocked the conversation" : "管理員解鎖了對話",
    "{actor} locked the conversation" : "{actor} 鎖定了對話",
    "You locked the conversation" : "您鎖定了對話",
    "An administrator locked the conversation" : "管理員鎖定了對話",
    "{actor} limited the conversation to the current participants" : "{actor} 將對話限制為目前參與者",
    "You limited the conversation to the current participants" : "您將對話限制為目前參與者",
    "An administrator limited the conversation to the current participants" : "管理員將對話限制為目前參與者",
    "{actor} opened the conversation to registered users" : "{actor} 已向註冊用戶開放對話",
    "You opened the conversation to registered users" : "您已向註冊用戶開放對話",
    "An administrator opened the conversation to registered users" : "管理員已向註冊用戶開放對話",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} 向已註冊用戶及以訪客(Guests)應用程式建立的用戶開放了對話",
    "You opened the conversation to registered users and users created with the Guests app" : "您向已註冊用戶及以訪客(Guests)應用程式建立的用戶開放了對話",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "管理員向已註冊用戶及以訪客(Guests)應用程式建立的用戶開放了對話",
    "The conversation is now open to everyone" : "對話現在向所有人開放",
    "{actor} opened the conversation to everyone" : "{actor} 向所有人開放了對話",
    "You opened the conversation to everyone" : "您向所有人開放了對話",
    "{actor} restricted the conversation to moderators" : "{actor} 將對話限制為主持人",
    "You restricted the conversation to moderators" : "您將對話限制為主持人",
    "{actor} started breakout rooms" : "{actor} 開始了分組討論室",
    "You started breakout rooms" : "您開始了分組討論室",
    "{actor} stopped breakout rooms" : "{actor} 停止了分組討論室",
    "You stopped breakout rooms" : "您停止了分組討論室",
    "{actor} allowed guests" : "{actor} 允許來賓加入對話",
    "You allowed guests" : "您允許來賓加入對話",
    "An administrator allowed guests" : "管理員允許來賓加入對話",
    "{actor} disallowed guests" : "{actor} 不允許來賓加入對話",
    "You disallowed guests" : "您不允許來賓加入對話",
    "An administrator disallowed guests" : "管理員不允許來賓加入對話",
    "{actor} set a password" : "{actor} 設置了密碼",
    "You set a password" : "您設置了密碼",
    "An administrator set a password" : "管理員設置了密碼",
    "{actor} removed the password" : "{actor} 刪除了密碼",
    "You removed the password" : "您刪除了密碼",
    "An administrator removed the password" : "管理員刪除了密碼",
    "{actor} added {user}" : "{actor} 添加了 {user}",
    "You joined the conversation" : "您加入了對話",
    "{actor} joined the conversation" : "{actor} 加入了對話",
    "You added {user}" : "您添加了 {user}",
    "{actor} added you" : "{actor} 添加了您",
    "An administrator added you" : "管理員添加了您",
    "An administrator added {user}" : "管理員添加了 {user}",
    "You left the conversation" : "你離開了對話",
    "{actor} left the conversation" : "{actor} 離開了對話",
    "{actor} removed {user}" : "{actor} 刪除了 {user}",
    "You removed {user}" : "您刪除了 {user}",
    "{actor} removed you" : "{actor} 刪除了您",
    "An administrator removed you" : "管理員刪除了您",
    "An administrator removed {user}" : "管理員刪除了 {user}",
    "{actor} invited {federated_user}" : "{actor} 邀請了 {federated_user}",
    "You invited {federated_user}" : "您邀請了 {federated_user}",
    "You accepted the invitation" : "您接受了邀請",
    "{actor} invited you" : "{actor} 邀請了您",
    "An administrator invited you" : "管理員邀請了您",
    "An administrator invited {federated_user}" : "管理員邀請了 {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} 接受了邀請",
    "{actor} removed {federated_user}" : "{actor} 移除了{federated_user}",
    "You removed {federated_user}" : "您移除了 {federated_user}",
    "You declined the invitation" : "您婉拒了邀請",
    "An administrator removed {federated_user}" : "管理員移除了 {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} 婉拒了邀請",
    "{actor} added group {group}" : "{actor} 添加了群組 {group}",
    "You added group {group}" : "您添加了群組 {group}",
    "An administrator added group {group}" : "管理員添加了群組 {group} ",
    "{actor} removed group {group}" : "{actor} 移除了群組 {group}",
    "You removed group {group}" : "您移除了群組 {group}",
    "An administrator removed group {group}" : "管理員已將群組 {group} 移除",
    "{actor} added team {circle}" : "{actor} 新增了團隊 {circle}",
    "You added team {circle}" : "您新增了團隊 {circle}",
    "An administrator added team {circle}" : "管理員新增了團隊 {circle}",
    "{actor} removed team {circle}" : "{actor} 移除了團隊 {circle}",
    "You removed team {circle}" : "您移除了團隊 {circle}",
    "An administrator removed team {circle}" : "管理員移除了團隊 {circle}",
    "{actor} added {phone}" : "{actor} 添加了 {phone}",
    "You added {phone}" : "您添加了 {phone}",
    "An administrator added {phone}" : "管理員添加了 {phone}",
    "{actor} removed {phone}" : "{actor} 移除了 {phone}",
    "You removed {phone}" : "您移除了 {phone}",
    "An administrator removed {phone}" : "管理員移除了 {phone}",
    "{actor} promoted {user} to moderator" : "{actor} 晉升 {user} 為主持人",
    "You promoted {user} to moderator" : "您晉升 {user} 為主持人",
    "{actor} promoted you to moderator" : "{actor} 晉升您為主持人",
    "An administrator promoted you to moderator" : "管理員晉升了您為主持人",
    "An administrator promoted {user} to moderator" : "管理員晉升了 {user} 為主持人",
    "{actor} demoted {user} from moderator" : "{actor} 將 {user} 從主持人降級",
    "You demoted {user} from moderator" : "您將 {user} 從主持人降級",
    "{actor} demoted you from moderator" : "{actor} 將您從主持人降級",
    "An administrator demoted you from moderator" : "管理員將您從主持人降級",
    "An administrator demoted {user} from moderator" : "管理員將 {user} 從主持人降級",
    "{actor} shared a file which is no longer available" : "{actor} 共享了一個不再可用的檔案",
    "You shared a file which is no longer available" : "您共享了一個不再可用的檔案",
    "File shares are currently not supported in federated conversations" : "在聯合對話中目前不支援檔案共享",
    "The shared location is malformed" : "分享位置格式錯誤",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} 設置了 Matterbridge 以將此對話與其他聊天同步",
    "You set up Matterbridge to synchronize this conversation with other chats" : "您設置了 Matterbridge 以將此對話與其他聊天同步",
    "{actor} created thread {title}" : "{actor} 建立了討論串 {title}",
    "You created thread {title}" : "您建立了討論串 {title}",
    "{actor} renamed thread {title}" : "{actor} 重新命名了討論串 {title}",
    "You renamed thread {title}" : "您重新命名了討論串 {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} 更新了 Matterbridge 的配置",
    "You updated the Matterbridge configuration" : "您更新了 Matterbridge 的配置",
    "{actor} removed the Matterbridge configuration" : "{actor} 刪除了 Matterbridge 的配置",
    "You removed the Matterbridge configuration" : "您刪除了 Matterbridge 的配置",
    "{actor} started Matterbridge" : "{actor} 啟動了Matterbridge",
    "You started Matterbridge" : "您啟動了Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} 停止了 Matterbridge",
    "You stopped Matterbridge" : "您停止了 Matterbridge",
    "{actor} deleted a message" : "{actor} 刪除了訊息",
    "You deleted a message" : "您刪除了訊息",
    "{actor} edited a message" : "{actor} 編輯了訊息",
    "You edited a message" : "您編輯了訊息",
    "{actor} pinned a message" : "{actor} 釘選了訊息",
    "You pinned a message" : "您釘選了訊息",
    "{actor} unpinned a message" : "{actor} 取消釘選了訊息",
    "Message was automatically unpinned" : "訊息已自動取消釘選",
    "You unpinned a message" : "您取消釘選了訊息",
    "{actor} deleted a reaction" : "{actor} 刪除了反應",
    "You deleted a reaction" : "您刪除了反應",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["您將訊息過期時間設置為%n星期"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["您將訊息過期時間設置為%n天"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["您將訊息過期時間設置為%n小時"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["您將訊息過期時間設置為%n分鐘"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} 將訊息過期時間設置為%n星期"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} 將訊息過期時間設置為%n天"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} 將訊息過期時間設置為%n小時"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} 將訊息過期時間設置為%n分鐘"],
    "{actor} disabled message expiration" : "{actor} 已停用訊息過期時間",
    "You disabled message expiration" : "您已停用訊息過期時間",
    "{actor} cleared the history of the conversation" : "{actor} 清除了對話的歷史記錄",
    "You cleared the history of the conversation" : "你清除了對話的歷史記錄",
    "{actor} set the conversation picture" : "{actor} 設置了對話圖片",
    "You set the conversation picture" : "您設置了對話圖片",
    "{actor} removed the conversation picture" : "{actor} 移除了對話圖片",
    "You removed the conversation picture" : "您移除了對話圖片",
    "{actor} ended the poll {poll}" : "{actor} 結束了投票 {poll}",
    "You ended the poll {poll}" : "您結束了投票 {poll}",
    "{actor} started the video recording" : "{actor} 開始錄影",
    "You started the video recording" : "您開始錄影",
    "{actor} stopped the video recording" : "{actor} 停止了錄影",
    "You stopped the video recording" : "您停止了錄影",
    "{actor} started the audio recording" : "{actor} 開始錄音",
    "You started the audio recording" : "您開始錄音",
    "{actor} stopped the audio recording" : "{actor} 停止了錄音",
    "You stopped the audio recording" : "您停止了錄音",
    "The recording failed" : "錄製失敗",
    "Someone voted on the poll {poll}" : "有人在民意調查 {poll} 中投票",
    "Message deleted by author" : "訊息被作者刪除",
    "Message deleted by {actor}" : "訊息被 {actor} 刪除",
    "Message deleted by you" : "訊息被您刪除",
    "Deleted user" : "已刪除的用戶",
    "Unknown number" : "號碼不詳",
    "Administration" : "管理",
    "System" : "系统",
    "%s (guest)" : "%s（訪客）",
    "Missed call" : "未接來電",
    "Unanswered call" : "未接通話",
    "Call ended (Duration {duration})" : "通話已結束（持續時間 {duration}）",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "通話因達到最長通話時長（持續時間 {duration}）而結束",
    "{actor} ended the call (Duration {duration})" : "{actor} 結束了通話（持續時間 {duration}）",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["與 %n 位訪客的通話因達到最長通話時間（持續時間 {duration}）而結束"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["與 %n 位訪客的通話結束（持續時間 {duration}）"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} 結束了與 %n 位客人的通話（持續時間 {duration}）"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "與{user1}的通話因達到最長通話時間（持續時間 {duration}）而結束",
    "Call with {user1} ended (Duration {duration})" : "與 {user1}的通話已結束（持續時間 {duration}）",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} 結束了與 {user1} 的通話（持續時間 {duration}）",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "與 {user1}及 {user2} 的通話因達到最長通話時間（持續時間 {duration}）而結束",
    "Call with {user1} and {user2} ended (Duration {duration})" : "與 {user1} 及 {user2} 通話結束（持續時間 {duration}）",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} 結束了與 {user1} 和 {user2} 的通話（持續時間 {duration}）",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "與 {user1}、{user2} 及 {user3} 的通話因達到最長通話時間（持續時間 {duration}）而結束",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "與 {user1}、{user2} 及 {user3} 通話結束（持續時間 {duration}）",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} 結束了與 {user1}、{user2} 和 {user3} 的通話（持續時間 {duration}）",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "與 {user1}、{user2}、{user3} 及 {user4} 的通話因達到最長通話時間（持續時間 {duration}）而結束",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "與 {user1}、{user2}、{user3} 及 {user4} 通話結束（持續時間 {duration}）",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} 結束了與 {user1}、{user2}、{user3} 和 {user4} 的通話（持續時間 {duration}）",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "與 {user1}、{user2}、{user3}、{user4} 及 {user5} 的通話因達到最長通話時間（持續時間 {duration}）而結束",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "與 {user1}、{user2}、{user3}、{user4} 及 {user5} 通話結束（持續時間 {duration}）",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} 結束了與 {user1}﹑{user2}﹑{user3}﹑{user4} 和 {user5} 的通話（持續時間 {duration}）",
    "Message of {user} in {conversation}" : "{conversation} 中 {user} 的訊息",
    "Message of {user}" : "{user} 的訊息",
    "Message of a deleted user in {conversation}" : "{conversation} 中已刪除用戶的訊息",
    "Talk conversations" : "Talk 對話",
    "Talk to %s" : "與 %s 通話",
    "An error occurred. Please contact your administrator." : "發生錯誤，請聯絡管理員。",
    "App disabled" : "已停用應用程式",
    "Conversation subfolders are disabled" : "已停用對話子資料夾",
    "Storage quota exceeded" : "超過儲存空間配額",
    "Could not prepare conversation folder" : "無法準備對話資料夾",
    "File not found" : "找不到檔案",
    "Path must point to a file" : "路徑必須指向檔案",
    "File is not inside the conversation draft folder for this room" : "檔案不在此聊天室的草稿資料夾中",
    "File is not shared, or shared but not with the user" : "檔案未分享，或未與用戶分享",
    "No account available to delete." : "沒有可刪除的帳戶。",
    "Poll" : "民意調查",
    "Password needs to be set" : "需要設定密碼",
    "Uploading the file failed" : "上傳檔案失敗",
    "No image file provided" : "未提供圖像",
    "File is too big" : "檔案太大",
    "Invalid file provided" : "提供的檔案無效",
    "Invalid image" : "圖像無效",
    "Unknown filetype" : "檔案類型不詳",
    "Talk mentions" : "Talk 提及",
    "More conversations" : "更多對話",
    "Say hi to your friends and colleagues!" : "跟大家打招呼",
    "No unread mentions" : "沒有未讀的 @提及",
    "Call in progress" : "正在通話中…",
    "You were mentioned" : "您被提及",
    "Write to conversation" : "寫到對話",
    "Writes event information into a conversation of your choice" : "將活動資訊寫入您選擇的對話中",
    "Missing email field in header line" : "標題行中缺少電郵地址欄位",
    "Following lines are invalid: %s" : "以下行無效：%s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s 邀請您加入對話「%2$s」。",
    "You were invited to conversation \"%s\"." : "您被邀請加入對話「%s」。",
    "Conversation invitation" : "對話邀請",
    "Scheduled time" : "排定時間",
    "Description" : "描述",
    "You can also dial-in via phone with the following details" : "您也可以使用以下細節通過電話撥入",
    "Dial-in information" : "撥入細節",
    "Meeting ID" : "會議 ID",
    "Your PIN" : "您的 PIN",
    "Click the button below to join the lobby now." : "點擊下方按鈕以立刻加入等候室。",
    "Click the link below to join the lobby now." : "點選下方連結以立刻加入等候室。",
    "Join lobby for \"%s\"" : "加入「%s」的等候室",
    "Click the button below to join the conversation now." : "點選下方按鈕以立刻加入對話。",
    "Click the link below to join the conversation now." : "點選下方連結以立刻加入對話。",
    "Join \"%s\"" : "加入「%s」",
    "Meeting" : "會議",
    "Password request: %s" : "索取密碼： %s",
    "Private conversation" : "私人對話",
    "Deleted user (%s)" : "已刪除用戶（%s）",
    "Failed to upload call recording" : "上傳通話錄音失敗",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "錄音伺服器無法上傳通話 {call} 的錄音。請聯絡管理員。",
    "Share to chat" : "分享至聊天",
    "Dismiss notification" : "撤銷通告",
    "Call recording now available" : "通話錄音現已可用",
    "The recording for the call in {call} was uploaded to {file}." : "{call} 中的通話錄音已上傳到 {file}。",
    "Transcript now available" : "通話抄本現已可用",
    "The transcript for the call in {call} was uploaded to {file}." : "{call} 中的通話抄本已上傳到 {file}。",
    "Failed to transcript call recording" : "通話錄音轉抄本失敗",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "伺服器無法為 {call} 中的通話在 {file} 處創建錄音抄本。請聯絡管理員。",
    "Call summary now available" : "通話摘要現已可用",
    "The summary for the call in {call} was uploaded to {file}." : "{call} 通話的摘要已上傳至 {file}。",
    "Failed to summarize call recording" : "通話錄音文字摘要失敗",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "伺服器無法為 {call} 中的通話在 {file} 處建立摘要。請聯絡管理員。",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} 邀請您加入在 {remoteServer} 上的 {roomName}",
    "Accept" : "接受",
    "Decline" : "婉拒",
    "{user1} invited you to a federated conversation" : "{user1} 邀請您加入聯合對話",
    "Someone reacted" : "有人回應了",
    "New message" : "新郵件",
    "Reminder" : "提醒",
    "Someone mentioned you" : "有人提及您",
    "Notification" : "通告",
    "Someone reacted in a private conversation" : "有人在私人對話中反應了",
    "You received a message in a private conversation" : "您在私人對話中收到訊息",
    "Reminder in a private conversation" : "私人對話中的提醒",
    "Someone mentioned you in a private conversation" : "有人在私人對話中提及您",
    "Notification in a private conversation" : "私人對話中的通知",
    "Reminder: You in {call}" : "提醒：您在 {call} 中",
    "Reminder: {user} in {call}" : "提醒：{user} 在 {call} 中",
    "Reminder: Deleted user in {call}" : "提醒：已刪除的用戶在 {call} 中",
    "Reminder: {guest} (guest) in {call}" : "提醒：{guest}（訪客）在 {call} 中",
    "Reminder: Guest in {call}" : "提醒：訪客在 {call} 中",
    "{user} reacted with {reaction}" : "{user} 使用 {reaction} 做出反應",
    "{user} reacted with {reaction} in {call}" : "{user} 在 {call} 中使用 {reaction} 做出反應",
    "Deleted user reacted with {reaction} in {call}" : "已刪除的使用者在 {call} 中使用 {reaction} 做出反應",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest}（訪客）在 {call} 中使用 {reaction} 做出反應",
    "Guest reacted with {reaction} in {call}" : "訪客在 {call} 中使用 {reaction} 做出反應",
    "{user} in {call}" : "{call} 中的 {user}",
    "Deleted user in {call}" : "{call} 中已刪除的 {user}",
    "{guest} (guest) in {call}" : "{call} 中的 {guest}（訪客）",
    "Guest in {call}" : "{call} 中的訪客",
    "{user} sent you a private message" : "{user} 向您發送了一條私人訊息",
    "{user} sent a message in conversation {call}" : "{user} 向對話 {call} 發送了一條訊息",
    "A deleted user sent a message in conversation {call}" : "刪除的用戶在對話 {call} 中發送了一條訊息",
    "{guest} (guest) sent a message in conversation {call}" : "{guest}（訪客）向對話 {call} 發送了一條訊息",
    "A guest sent a message in conversation {call}" : "一位訪客向對話 {call} 發送了一條訊息",
    "{user} replied to your private message" : "{user} 回覆了您的私人留言",
    "{user} replied to your message in conversation {call}" : "{user} 在對話 {call} 中回覆了您的訊息",
    "A deleted user replied to your message in conversation {call}" : "刪除的用戶在對話 {call} 中回覆了您的訊息",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest}（guest）在對話 {call} 中回覆了您的訊息",
    "A guest replied to your message in conversation {call}" : "一位來賓在對話 {call} 中回覆了您的訊息",
    "Reminder: You in private conversation {call}" : "提醒：您在私人對話 {call} 中",
    "Reminder: A deleted user in private conversation {call}" : "提醒：已刪除的用戶在私人對話 {call} 中",
    "Reminder: {user} in private conversation" : "提醒：{user} 在私人對話中",
    "Reminder: You in conversation {call}" : "提醒：您在對話 {call} 中",
    "Reminder: {user} in conversation {call}" : "提醒：{user} 在對話 {call} 中",
    "Reminder: A deleted user in conversation {call}" : "提醒：已刪除的用戶在對話 {call} 中",
    "Reminder: {guest} (guest) in conversation {call}" : "提醒：{guest}（訪客）在對話 {call} 中",
    "Reminder: A guest in conversation {call}" : "提醒：訪客在對話 {call} 中",
    "{user} reacted with {reaction} to your private message" : "{user} 對您的私人訊息做出了 {reaction} 的反應",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} 在對話 {call} 中對您的訊息做出了 {reaction} 反應",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "已刪除 {user} 在對話 {call} 中對您的訊息做出了 {reaction} 反應",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "來賓 {guest} 在對話 {call} 中對您的訊息做出了 {reaction} 反應",
    "A guest reacted with {reaction} to your message in conversation {call}" : "來賓 {guest} 在對話 {call} 中對您的訊息做出了 {reaction} 反應",
    "{user} mentioned you in a private conversation" : "{user} 在私人對話中提及您",
    "{user} mentioned group {group} in conversation {call}" : "{user} 在對話 {call} 中提及群組 {group}",
    "{user} mentioned team {team} in conversation {call}" : "{user} 在對話 {call} 中提及團隊 {team}",
    "{user} mentioned everyone in conversation {call}" : "{user} 在對話 {call} 中提及所有人",
    "{user} mentioned you in conversation {call}" : "{user} 在對話 {call} 中提及您",
    "A deleted user mentioned group {group} in conversation {call}" : "一位已刪除的用戶在對話 {call} 中提及群組 {group}",
    "A deleted user mentioned team {team} in conversation {call}" : "一位已刪除的用戶在對話 {call} 中提及團隊 {team}",
    "A deleted user mentioned everyone in conversation {call}" : "一位已刪除的用戶在對話 {call} 中提及所有人",
    "A deleted user mentioned you in conversation {call}" : "一位已刪除的用戶在對話 {call} 中提及您",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest}（訪客）在對話 {call} 中提及群組 {group}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest}（訪客）在對話 {call} 中提及團隊 {team}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest}（訪客）在對話 {call} 中提及所有人",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest}（訪客）在對話 {call} 中提及您",
    "A guest mentioned group {group} in conversation {call}" : "一位訪客在對話 {call} 中提及群組 {group}",
    "A guest mentioned team {team} in conversation {call}" : "一位訪客在對話 {call} 中提及團隊 {team}",
    "A guest mentioned everyone in conversation {call}" : "一位訪客在對話 {call} 中提及所有人",
    "A guest mentioned you in conversation {call}" : "一位訪客在對話 {call} 中提及您",
    "View message" : "檢視訊息",
    "Dismiss reminder" : "撤銷提醒",
    "View chat" : "檢視聊天",
    "{user} invited you to a group conversation: {call}" : "{user} 邀請您參加群組對話：{call}",
    "Join call" : "加入通話",
    "Answer call" : "接聽通話",
    "{user} would like to talk with you" : "{user} 想與您交談",
    "Call back" : "回電",
    "You missed a call from {user}" : "您錯過了 {user} 的來電",
    "Accept call" : "接聽通話",
    "Incoming phone call from {call}" : "{call} 的來電",
    "You missed a phone call from {call}" : "您錯過了 {call} 的來電",
    "A group call has started in {call}" : "{call} 中的群組通話已開始",
    "You missed a group call in {call}" : "您錯過了 {call} 中的群組通話",
    "{email} is requesting the password to access {file}" : "{email} 請求密碼以存取 {file}",
    "{email} tried to request the password to access {file}" : "{email} 嘗試請求密碼以存取 {file}",
    "Someone is requesting the password to access {file}" : "有人請求密碼以存取 {file}",
    "Someone tried to request the password to access {file}" : "有人嘗試請求密碼以存取 {file}",
    "Open settings" : "開啟設定",
    "Hosted signaling server added" : "添加了架設好的訊號伺服器",
    "The hosted signaling server is now configured and will be used." : "已配置好託管的信號伺服器並將被使用。",
    "Hosted signaling server removed" : "已移除架設好的訊號伺服器",
    "The hosted signaling server was removed and will not be used anymore." : "託管的信號伺服器已刪除，將不再使用。",
    "Hosted signaling server changed" : "已更新架設好的訊號伺服器",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "託管的信令伺服器帳戶已將狀態從 “ {oldstatus}” 更改為 “{newstatus}”。",
    "pending" : "待定",
    "active" : "啟用",
    "expired" : "已過期",
    "blocked" : "被封鎖",
    "error" : "錯誤",
    "The certificate of {host} expires in {days} days" : "{host} 的證書將在 {days} 天後過期",
    "The certificate of {host} expired" : "{host} 的證書已過期",
    "Contact via Talk" : "透過 Talk 聯絡",
    "Open Talk" : "開啟 Talk",
    "Default" : "默認",
    "Send messages, create threads, and start voice and video calls." : "傳送訊息、建立討論串、開始音訊與視訊通話。",
    "Presentation" : "簡報",
    "Voice room" : "語音聊天室",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "直接加入通話，非常適合閒聊或臨時開會。",
    "Webinar" : "網絡研討會",
    "Conversations" : "對話",
    "Messages in current conversation" : "目前對話中的訊息",
    "{user}" : "{user}",
    "Messages" : "訊息",
    "{user} in {conversation}" : "{conversation} 中的 {user}",
    "Messages in other conversations" : "其他對話中的訊息",
    "One-to-one rooms always need to show the other users avatar" : "一對一的房間一律需要顯示其他用戶的虛擬化身",
    "Invalid emoji character" : "無效的 emoji 字元",
    "Invalid background color" : "無效的背景顏色",
    "Avatar image is not square" : "虛擬化身圖像不是正方形",
    "Room {number}" : "聊天室 {number}",
    "Other" : "其它",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "由於聯繫不到試用伺服器，因此無法請求試用。請稍後再試。",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "此安裝的身分驗證存在問題。可能無法從外部訪問以驗證其URL。",
    "Something unexpected happened." : "發生了意外情況。",
    "The URL is invalid." : "URL 無效。",
    "An HTTPS URL is required." : "需要 HTTPS URL。",
    "The email address is invalid." : "電郵地址無效。",
    "The language is invalid." : "語言無效。",
    "The country is invalid." : "國家無效。",
    "There is a problem with the request of the trial. Please check your logs for further information." : "試用請求有問題。請檢查您的記錄以獲取更多資訊。",
    "Too many requests are send from your servers address. Please try again later." : "您的伺服器地址發送了太多請求。請稍後再試。",
    "There is already a trial registered for this Nextcloud instance." : "此 Nextcloud 實例已經有一個試用用戶註冊。",
    "Something unexpected happened. Please try again later." : "發生了意外情況。請稍後再試。",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "由於試用伺服器的行為不正確，因此無法請求試用。請稍後再試。",
    "Trial requested but failed to get account information. Please check back later." : "已請求試用，但無法獲取帳戶信息。請稍後再試。",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "此請求的身分驗證存在問題。也許無法從外部聯繫它以驗證其URL。",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "由於試用伺服器的行為異常，因此無法擷取帳戶資訊。請稍後再試。",
    "There is a problem with fetching the account information. Please check your logs for further information." : "提取帳戶資訊時出現問題。請檢查您的日誌以獲取更多資訊。",
    "There is no such account registered." : "沒有這樣的帳戶註冊。",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "由於無法連接試用伺服器，因此無法擷取帳戶資訊。請稍後再試。",
    "Deleting the hosted signaling server account failed. Please check back later." : "刪除託管的信令伺服器帳戶失敗。請稍後再試。",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "由於試用伺服器的行為異常，因此無法刪除帳戶。請稍後再試。",
    "There is a problem with deleting the account. Please check your logs for further information." : "刪除帳戶存在問題。請檢查系統日誌以獲取更多信息。",
    "Too many requests are sent from your servers address. Please try again later." : "您的伺服器地址發送了太多請求。請稍後再試。",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "由於無法訪問試用伺服器，因此無法刪除帳戶。請稍後再檢查。",
    "Note to self" : "給自己的備註",
    "A place for your private notes, thoughts and ideas" : "一個用於儲存您的私人筆記、思考和想法的地方。",
    "Transcript is AI generated and may contain mistakes" : "轉錄為人工智慧產生，可能有錯",
    "Summary is AI generated and may contain mistakes" : "摘要為人工智慧產生，可能有錯",
    "Let's get started!" : "我們開始吧！",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** 是一個安全的自托管通訊平台，與 Nextcloud 生態系統無縫集成。\n\n#### Nextcloud Talk 的重要功能：\n\n* 在私人與群組聊天中傳送訊息\n* 音訊與視訊通話\n* 檔案分享以及其他 Nextcloud 應用程式的整合\n* 可自訂的對話設定、審核與隱私控制\n* 網頁、桌面與行動裝置（iOS 與 Android）\n* 私密且安全的通訊\n\n如需了解更多信息，請參見[用戶說明書] (https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)。",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# 歡迎使用 Nextcloud Talk\n\nNextcloud Talk 是與 Nextcloud 整合的私密且功能強大的訊息應用程式。以私人或群組對話方式聊天、透過語音與視訊通話進行協作、舉辦網路研討會與活動、自訂您的對話等。",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 格式化文字以建立多采多姿的訊息\n\n在 Nextcloud Talk 中，您可以使用 Markdown 語法來格式化您的訊息。例如，套用**粗體**或*義式斜體*格式，或「將文字突顯為程式碼」。您甚至可以建立表格，並在文字中加入標題。\n\n需要修正錯字或變更格式嗎？按一下訊息功能表中的「編輯訊息」即可編輯您的訊息。",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 新增附件與連結\n\n使用「+」按鈕從 Nextcloud Hub 附加檔案。從檔案與各種 Nextcloud 應用程式分享項目。有些應用程式甚至支援互動小工具，例如 Text 應用程式。",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 讓對話流暢：提及用戶、回應訊息等\n\n您可以使用 %s 來提及對話中的每個人，或是輸入「@」並從清單中選出特定參與者的名字來提及他們。",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "您可以回覆訊息、將訊息轉寄給其他聊天室與夥伴，或複製訊息內容。",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ 使用智慧型挑選程式做更多\n\n只要輸入「/」或前往「+」功能表，即可開啟智慧型挑選程式，在這裡您可以將各種內容附加到訊息中。您可以設定智慧型挑選程式，讓它能夠加入 Nextcloud 應用程式、GIF、地圖位置、AI 產生的內容等項目。",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ 管理對話設定\n\n在對話功能表中，您可以存取各種設定來管理您的對話，例如\n* 編輯對話資訊\n* 管理通知\n* 套用許多審核規則\n* 設定存取權限與安全性\n* 啟用機器人\n* 以及更多！",
    "Andorra" : "安道爾",
    "United Arab Emirates" : "阿聯酋",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安提瓜和巴布達",
    "Anguilla" : "安圭拉",
    "Albania" : "阿爾巴尼亞",
    "Armenia" : "亞美尼亞",
    "Angola" : "安哥拉",
    "Antarctica" : "南極洲",
    "Argentina" : "阿根廷",
    "American Samoa" : "美屬薩摩亞",
    "Austria" : "奧地利",
    "Australia" : "澳洲",
    "Aruba" : "阿魯巴",
    "Åland Islands" : "奧蘭",
    "Azerbaijan" : "阿塞拜疆",
    "Bosnia and Herzegovina" : "波斯尼亞及黑塞哥維那",
    "Barbados" : "巴巴多斯",
    "Bangladesh" : "孟加拉",
    "Belgium" : "比利時",
    "Burkina Faso" : "布基納法索",
    "Bulgaria" : "保加利亞",
    "Bahrain" : "巴林",
    "Burundi" : "布隆迪",
    "Benin" : "貝寧",
    "Saint Barthélemy" : "聖巴瑟米",
    "Bermuda" : "百慕達",
    "Brunei Darussalam" : "汶萊",
    "Bolivia, Plurinational State of" : "玻利維亞",
    "Bonaire, Sint Eustatius and Saba" : "荷蘭加勒比區",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈馬",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布韋島",
    "Botswana" : "博茨瓦納",
    "Belarus" : "白俄羅斯",
    "Belize" : "伯利茲",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯（基林）群島",
    "Congo, the Democratic Republic of the" : "剛果民主共和國",
    "Central African Republic" : "中非共和國",
    "Congo" : "剛果共和國",
    "Switzerland" : "瑞士",
    "Côte d'Ivoire" : "科特迪瓦",
    "Cook Islands" : "庫克群島",
    "Chile" : "智利",
    "Cameroon" : "喀麥隆",
    "China" : "中國大陸",
    "Colombia" : "哥倫比亞",
    "Costa Rica" : "哥斯達黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "佛得角",
    "Curaçao" : "古拉索",
    "Christmas Island" : "聖誕島領地",
    "Cyprus" : "塞浦路斯",
    "Czechia" : "捷克",
    "Germany" : "德國",
    "Djibouti" : "吉布提",
    "Denmark" : "丹麥",
    "Dominica" : "多米尼克",
    "Dominican Republic" : "多明尼加共和國",
    "Algeria" : "阿爾及利亞",
    "Ecuador" : "厄瓜多爾",
    "Estonia" : "愛沙尼亞",
    "Egypt" : "埃及",
    "Western Sahara" : "西撒哈拉",
    "Eritrea" : "厄立特里亞",
    "Spain" : "西班牙",
    "Ethiopia" : "埃塞俄比亞",
    "Finland" : "芬蘭",
    "Fiji" : "斐濟",
    "Falkland Islands (Malvinas)" : "福克蘭群島",
    "Micronesia, Federated States of" : "密克羅尼西亞聯邦",
    "Faroe Islands" : "法羅群島",
    "France" : "法國",
    "Gabon" : "加蓬",
    "United Kingdom of Great Britain and Northern Ireland" : "英國",
    "Grenada" : "格林納達",
    "Georgia" : "格魯吉亞",
    "French Guiana" : "法屬圭亞那",
    "Guernsey" : "根西島",
    "Ghana" : "迦納",
    "Gibraltar" : "直布羅陀",
    "Greenland" : "格陵蘭",
    "Gambia" : "岡比亞",
    "Guinea" : "幾內亞",
    "Guadeloupe" : "瓜地洛普",
    "Equatorial Guinea" : "赤道幾內亞",
    "Greece" : "希臘",
    "South Georgia and the South Sandwich Islands" : "南喬治亞和南桑威奇群島",
    "Guatemala" : "危地馬拉",
    "Guam" : "關島",
    "Guinea-Bissau" : "幾內亞比紹",
    "Guyana" : "圭亞那",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德島和麥克唐納群島",
    "Honduras" : "洪都拉斯",
    "Croatia" : "克羅地亞",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印尼",
    "Ireland" : "愛爾蘭",
    "Israel" : "以色列",
    "Isle of Man" : "萌島",
    "India" : "印度",
    "British Indian Ocean Territory" : "英屬印度洋領地",
    "Iraq" : "伊拉克",
    "Iran, Islamic Republic of" : "伊朗",
    "Iceland" : "冰島",
    "Italy" : "意大利",
    "Jersey" : "澤西島",
    "Jamaica" : "牙買加",
    "Jordan" : "約旦",
    "Japan" : "日本",
    "Kenya" : "肯亞",
    "Kyrgyzstan" : "吉爾吉斯斯坦",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "基里巴斯",
    "Comoros" : "科摩羅",
    "Saint Kitts and Nevis" : "聖吉斯納域斯",
    "Korea, Democratic People's Republic of" : "北韓",
    "Korea, Republic of" : "南韓",
    "Kuwait" : "科威特",
    "Cayman Islands" : "開曼群島",
    "Kazakhstan" : "哈薩克",
    "Lao People's Democratic Republic" : "老撾",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "聖露西亞",
    "Liechtenstein" : "列支敦士登",
    "Sri Lanka" : "斯里蘭卡",
    "Liberia" : "利比里亞",
    "Lesotho" : "萊索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "盧森堡",
    "Latvia" : "拉脫維亞",
    "Libya" : "利比亞",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩納哥",
    "Moldova, Republic of" : "摩爾多瓦共和國",
    "Montenegro" : "黑山",
    "Saint Martin (French part)" : "法屬聖馬丁島",
    "Madagascar" : "馬達加斯加",
    "Marshall Islands" : "馬紹爾群島",
    "North Macedonia" : "北馬其頓",
    "Mali" : "馬里",
    "Myanmar" : "緬甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳門",
    "Northern Mariana Islands" : "北馬利安納群島",
    "Martinique" : "馬丁尼克",
    "Mauritania" : "毛里塔尼亞",
    "Montserrat" : "蒙特塞拉特",
    "Malta" : "馬爾他",
    "Mauritius" : "毛里求斯",
    "Maldives" : "馬爾代夫",
    "Malawi" : "馬拉維",
    "Mexico" : "墨西哥",
    "Malaysia" : "馬來西亞",
    "Mozambique" : "莫桑比克",
    "Namibia" : "納米比亞",
    "New Caledonia" : "新喀里多尼亞",
    "Niger" : "尼日爾",
    "Norfolk Island" : "諾福克島",
    "Nigeria" : "尼日利亞",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷蘭",
    "Norway" : "挪威",
    "Nepal" : "尼泊爾",
    "Nauru" : "瑙魯",
    "Niue" : "紐埃島",
    "New Zealand" : "紐西蘭",
    "Oman" : "阿曼",
    "Panama" : "巴拿馬",
    "Peru" : "秘魯",
    "French Polynesia" : "法屬波利尼西亞",
    "Papua New Guinea" : "巴布亞新幾內亞",
    "Philippines" : "菲律賓",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波蘭",
    "Saint Pierre and Miquelon" : "聖皮埃與密克隆群島",
    "Pitcairn" : "皮特肯群島",
    "Puerto Rico" : "波多黎各",
    "Palestine, State of" : "巴勒斯坦",
    "Portugal" : "葡萄牙",
    "Palau" : "帕勞",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡塔爾",
    "Réunion" : "留尼旺島",
    "Romania" : "羅馬尼亞",
    "Serbia" : "塞爾維亞",
    "Russian Federation" : "俄羅斯",
    "Rwanda" : "盧旺達",
    "Saudi Arabia" : "沙地阿拉伯",
    "Solomon Islands" : "所羅門群島",
    "Seychelles" : "塞舌爾",
    "Sudan" : "蘇丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "聖赫勒拿、阿森松和特里斯坦-達庫尼亞",
    "Slovenia" : "斯洛文尼亞",
    "Svalbard and Jan Mayen" : "斯瓦爾巴和揚馬延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "塞拉利昂",
    "San Marino" : "聖馬力諾",
    "Senegal" : "塞內加爾",
    "Somalia" : "索馬里",
    "Suriname" : "蘇利南",
    "South Sudan" : "南蘇丹",
    "Sao Tome and Principe" : "聖多美和普林西比",
    "El Salvador" : "薩爾瓦多",
    "Sint Maarten (Dutch part)" : "荷屬聖馬丁",
    "Syrian Arab Republic" : "敘利亞",
    "Eswatini" : "史瓦濟蘭王國",
    "Turks and Caicos Islands" : "特克斯及凱科斯群島",
    "Chad" : "乍得共和國",
    "French Southern Territories" : "法屬南部和南極領地",
    "Togo" : "多哥",
    "Thailand" : "泰國",
    "Tajikistan" : "塔吉克斯坦",
    "Tokelau" : "托克勞",
    "Timor-Leste" : "東帝汶",
    "Turkmenistan" : "土庫曼",
    "Tunisia" : "突尼西亞",
    "Tonga" : "湯加",
    "Turkey" : "土耳其",
    "Trinidad and Tobago" : "千里達及多巴哥",
    "Tuvalu" : "圖瓦盧",
    "Taiwan, Province of China" : "台灣，中華民國",
    "Tanzania, United Republic of" : "坦桑尼亞",
    "Ukraine" : "烏克蘭",
    "Uganda" : "烏干達",
    "United States Minor Outlying Islands" : "美國本土外小島嶼",
    "United States of America" : "美國",
    "Uruguay" : "烏拉圭",
    "Uzbekistan" : "烏茲別克",
    "Holy See" : "梵蒂岡",
    "Saint Vincent and the Grenadines" : "聖文森特和格林納丁斯",
    "Venezuela, Bolivarian Republic of" : "委內瑞拉",
    "Virgin Islands, British" : "英屬處女群島",
    "Virgin Islands, U.S." : "美屬處女群島",
    "Viet Nam" : "越南",
    "Vanuatu" : "瓦努阿圖",
    "Wallis and Futuna" : "瓦利斯和富圖那",
    "Samoa" : "薩摩亞",
    "Yemen" : "也門",
    "Mayotte" : "馬約特",
    "South Africa" : "南非",
    "Zambia" : "贊比亞",
    "Zimbabwe" : "津巴布韋",
    "Background blur" : "背景模糊",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "無法檢查 WASM 載入支援。請手動檢查您的網路伺服器是否可服務 `.wasm` 檔案。",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "您的伺服器並未正確的設定，因此無法傳遞 `.wasm` 的檔案。這通常是因為 Nginx 的設定問題所導致。對於背景模糊來說，需要一些調整才能一併傳遞 `.wasm` 的檔案。請檢查您的 Nginx 設定，和 Nextcloud 說明書中提到的建議設定。",
    "Talk configuration values" : "Talk 設定值",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "僅系統 cron 支援強制通話持續時間。請啟用系統 cron 或刪除 `max_call_duration` 配置。",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "由於技術限制，較小的 “max_call_duration” 值（目前設定為 %d）不可強制執行。後台作業每 5 分鐘執行一次，因此使用風險自負。",
    "Federation" : "聯盟",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "強烈建議在啟用聯盟 Talk 時設定「memcache.locking」。",
    "High-performance backend" : "高性能後端",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "未設定高效能後端 - 在沒有高效能後端的情況下執行 Nextcloud Talk 只適用於非常小規模的通話（最多 2-3 名參與者）。請設定高效能後端，以確保有多位參與者的通話能順暢運作。",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "高效能後端的「conversation_cluster」執行模式已棄用，在即將推出的版本中將不再支援。高效能後端現在支援真正的叢集，應該改用真正的叢集。",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "定義多個高效能後端已被淘汰，在即將推出的版本中將不再支援。取而代之的是在 Talk 設定中設定負載平衡器與叢集訊號伺服器。",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "所使用演算法 %1$s 的已儲存公鑰與儲存的私鑰不相符。請執行 %2$s 以修正問題。",
    "High-performance backend not configured correctly. Run %s for details." : "未正確設定高效能後端。請執行 %s 以取得更多詳細資訊。",
    "High-performance backend not configured correctly" : "未正確設定高效能後端",
    "Error: Cannot connect to server" : "錯誤：無法連接到伺服器",
    "Error: Server did not respond with proper JSON" : "錯誤：伺服器未使用正確的 JSON 回應",
    "Error: Certificate expired" : "錯誤︰證書已過期",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "錯誤：Nextcloud 伺服器和 High-performance 後端伺服器的系統時間不同步。請確保兩個伺服器都連接到時間伺服器，或手動同步它們的時間。",
    "Could not get version" : "無法獲取版本",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "錯誤：運行版本：{version}; 要與此版本的 Talk 兼容，伺服器需要更新",
    "Error: Server responded with: {error}" : "錯誤：伺服器回應：{error}",
    "Error: Unknown error occurred" : "錯誤：發生不詳錯誤",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "警告：正在執行的版本：{version}；伺服器不支援此 Talk 版本的所有功能，缺少的功能：{features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "強烈建議在使用高效能後端執行 Nextcloud Talk 時設定記憶體快取。",
    "Client Push" : "客戶端推送",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "已安裝客戶端推送，這會改善 Talk 通知的及時性。",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} 未安裝。這可能會導致 Talk 通知延遲。",
    "Recording backend" : "記録後端系統中",
    "Using the recording backend requires a High-performance backend." : "使用錄製後端需要高效能後端。",
    "No recording backend configured" : "未設定錄製後端",
    "SIP configuration" : "SIP 配置",
    "Using the SIP functionality requires a High-performance backend." : "使用 SIP 功能需要高效能後端。",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "分配的 Talk 電話號碼不得以 + 或 0 開頭。請移除或更新以下號碼：\n{list}",
    "No SIP backend configured" : "未設定 SIP 後端系統",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Conversation not found" : "未找到對話",
    "Path is already shared with this conversation" : "已與此對話分享路徑",
    "Chat, video & audio-conferencing using WebRTC" : "使用 WebRTC 進行聊天、視像和音頻會議",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "使用 WebRTC 的聊天、視頻和音頻會議\n\n* 💬 **聊天** Nextcloud Talk 提供簡單的文本聊天功能，允許您從 Nextcloud Files 應用程式或近端裝置分享或上傳檔案，並提及其他參與者。\n* 👥 **私人、小組、公開和密碼保護的通話！** 邀請某人、整個小組或發送公開鏈接來邀請參加通話。\n* 🌐 **聯邦式聊天** 與其他 Nextcloud 用戶在他們的服務器上聊天。\n* 💻 **屏幕共享！** 與通話的參與者共享您的屏幕。\n* 🚀 **與其他 Nextcloud 應用集成**，如 Files、Calendar、User status、Dashboard、Flow、Maps、Smart picker、Contacts、Deck 等，還有更多。\n* 🌉 **與其他聊天解決方案同步** 通過 [Matterbridge](https://github.com/42wim/matterbridge/) 在 Talk 中集成，您可以輕鬆將許多其他聊天解決方案與 Nextcloud Talk 進行同步，反之亦然。",
    "Leave call" : "離開通話",
    "Navigating away from the page will leave the call in {conversation}" : "離開頁面導航將使通話保留在 {conversation} 中",
    "Stay in call" : "保持通話",
    "Error occurred when getting the conversation information" : "取得對話資訊時發生錯誤",
    "Discuss this file" : "討論此檔案",
    "Share this file with others to discuss it" : "與他人分享此檔案以進行討論",
    "Share this file" : "分享此檔案",
    "Join conversation" : "加入對話",
    "This conversation is password-protected." : "此對話受密碼保護。",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "您的 IP 多次嘗試密碼無效，下一次登入將會被延時 30 秒。",
    "The password is wrong. Try again." : "密碼錯誤，請重試",
    "Password" : "密碼",
    "Submit" : "遞交",
    "Error requesting the password." : "索取密碼時出錯。",
    "Request password" : "索取密碼",
    "This conversation has ended" : "對話已結束",
    "Error occurred when joining the conversation" : "加入會話時發生了錯誤",
    "Close Talk sidebar" : "關閉 Talk 側邊攔",
    "Open Talk sidebar" : "開啟 Talk 側邊攔",
    "Everyone" : "所有人",
    "Users and moderators" : "用戶和主持人",
    "Moderators only" : "僅限主持人",
    "Disable calls" : "停用通話",
    "Save changes" : "儲存變更",
    "Saving …" : "儲存中 ...",
    "Saved!" : "已儲存!",
    "Limit to groups" : "限制給特定群組",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "選擇一或多個群組後，只有所選群組中的人才能參與對話。",
    "Guests can still join public conversations." : "來賓仍可以加入公共對話。",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "不再使用 Talk 的用戶仍將被列為以前的對話的參與者。他們的聊天訊息將被保留。",
    "Limit using Talk" : "使用 Talk 的限制",
    "Limit creating a public and group conversation" : "創建公開和群組對話的限制",
    "Limit creating conversations" : "創建對話的限制",
    "Limit starting a call" : "限制撥打通話",
    "Limit starting calls" : "限制撥打通話",
    "When a call has started, everyone with access to the conversation can join the call." : "通話開始後，有權存取對話的每個人都可以加入通話。",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "此伺服器上安裝了以下機器人。在文件中，您可以找到如何{linkstart1}建構您自己的機器人{linkend}，或是可以在您的伺服器上啟用的{linkstart2}機器人清單{linkend}。",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "此伺服器上並未安裝機器人。在文件中，您可以找到如何{linkstart1}建構您自己的機器人{linkend}，或是可以在您的伺服器上啟用的{linkstart2}機器人清單{linkend}。",
    "Description is not provided" : "未提供描述",
    "Locked for moderators" : "為主持人鎖定",
    "Enabled" : "啟用",
    "Disabled" : "停用",
    "Bots settings" : "機器人設定",
    "State" : "狀態",
    "Name" : "名稱",
    "Last error" : "上次錯誤",
    "Total errors count" : "總錯誤數量",
    "Find more bots" : "尋找更多機器人",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "可以在{linkstart}分享設定頁面{linkedin}設定信任伺服器。",
    "Beta" : "Beta 測試版",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "聯盟聊天與通話已經可以運作。附件處理將在未來的版本中推出。",
    "Enable Federation in Talk app" : "啟用 Talk 應用程式中的聯邦功能",
    "Permissions" : "權限",
    "Allow users to be invited to federated conversations" : "允許邀請用戶加入聯合對話",
    "Allow users to invite federated users into conversation" : "允許用戶邀請聯合用戶加入對話",
    "Only allow to federate with trusted servers" : "僅允許與信任的伺服器聯合",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "選擇一或多個群組後，只有所選群組中的人才能邀請聯合用戶到對話中。",
    "Groups allowed to invite federated users" : "允許邀請聯合用戶的群組",
    "Select groups …" : "選取群組 …",
    "All messages" : "全部消息",
    "@-mentions only" : "僅被 @提及的消息",
    "Off" : "關閉",
    "General settings" : "一般設定",
    "Default notification settings" : "預設通告設定",
    "Default group notification" : "預設群組通告",
    "Default group notification for new groups" : "新群組的默認群組通告",
    "Integration into other apps" : "整合=到其他應用程序",
    "Allow conversations on files" : "允許檔案對話",
    "Allow conversations on public shares for files" : "允許公共分享檔案對話",
    "End-to-end encrypted calls" : "端到端加密通話",
    "Enable encryption" : "啟用加密",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "使用已設定 SIP 橋接的端到端加密通話需要較新版本的高效能後端與 SIP 橋接器。",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "行動裝置客戶端目前不支援端到端加密通話。",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "通過單擊上面的按鈕，表格中的資訊將發送到 Struktur AG 的伺服器。您可以在{linkstart} spreed.eu {linkend}上找到更多資訊。",
    "Pending" : "擱置中",
    "Error" : "錯誤",
    "Blocked" : "已封鎖",
    "Active" : "啟動",
    "Expired" : "已過期",
    "Never" : "從不",
    "The trial could not be requested. Please try again later." : "無法請求試用版。請稍後再試。",
    "The account could not be deleted. Please try again later." : "無法刪除該帳戶。請稍後再試。",
    "Hosted High-performance backend" : "託管的高效能後端",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "我們的合作夥伴 Struktur AG 提供信令伺服器的託管服務。您只需要填寫下面的表格，您的 Nextcloud 就會為您申請該服務。為您設置伺服器後，將自動填寫憑據。這將覆蓋現有的信令伺服器設置。",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "如果您的高性能後端系統帳戶包括 STUN 和/或 TURN 功能，設定將被相應更新。",
    "URL of this Nextcloud instance" : "此Nextcloud的 URL",
    "Full name of the user requesting the trial" : "請求試用的用戶的全名",
    "Email of the user" : "用戶電郵地址",
    "Language" : "語言",
    "Country" : "國家",
    "Request signaling server trial" : "請求信號伺服器試用",
    "You can see the current status of your hosted signaling server in the following table." : "您可以在下表中查看託管的信令伺服器的目前狀態。",
    "Status" : "狀態",
    "Created at" : "建立於",
    "Expires at" : "有效期至",
    "Limits" : "限制",
    "STUN included" : "包括 STUN",
    "Yes" : "是",
    "No" : "否",
    "TURN included" : "包括 TURN",
    "Delete the signaling server account" : "刪除 signaling 伺服器帳戶",
    "_%n user_::_%n users_" : ["%n 用戶"],
    "Installed version: {version}" : "安裝版本： {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "您可以安裝 Matterbridge 將 Nextcloud Talk 連結到其他服務，請訪問其 {linkstart1}GitHub頁面{linkend} 以了解更多詳細信息。下載和安裝該應用程式可能需要一段時間。如果超時，請從 {linkstart2}Nextcloud App Store{linkend} 人手安裝。",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge binary 的權限不正確。請確保 Matterbridge binary 歸正確的用戶所有並且可以執行。可以在 \"/…/nextcloud/apps/talk_matterbridge/bin/\" 中找到。",
    "Matterbridge binary was not found or couldn't be executed." : "找不到或無法執行 Matterbridge 可執行代碼。",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "您也可以通過人手設置 Matterbridge 可執行代碼的路徑。詳情請參閱 {linkstart} Matterbridge 整合指南{linkend}。",
    "Downloading …" : "下載中…",
    "Install Talk Matterbridge" : "安裝 Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "安裝 Matterbridge 應用程式時發生錯誤",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "安裝 Talk Matterbridge 時發生錯誤。請手動安裝。",
    "Failed to execute Matterbridge binary." : "無法執行 Matterbridge。",
    "Matterbridge integration" : "Matterbridge 整合",
    "Enable Matterbridge integration" : "啟用 Matterbridge 整合",
    "Status: Checking connection" : "狀態：正在檢查連接",
    "OK: Running version: {version}" : "OK：運行版本：{version}",
    "Error: Server seems to be a Signaling server" : "錯誤：伺服器似乎是 Signaling 伺服器",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "錯誤：Nextcloud 伺服器和 Recording 後端伺服器的系統時間不同步。請確保兩個伺服器都連接到時間伺服器，或手動同步它們的時間。",
    "Recording backend URL" : "錄製後端系統 URL",
    "Validate SSL certificate" : "驗證 SSL憑證",
    "Delete this server" : "刪除此伺服器",
    "Test this server" : "測試此伺服器",
    "Disabled for all calls" : "對所有通話停用",
    "Enabled for all calls" : "對所有通話啟用",
    "Configurable on conversation level by moderators" : "可由主持人在對話層級配置",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP 設定「upload_max_filesize」或「post_max_size」僅允許上傳最大 {maxUpload} 的檔案。",
    "Recording backend settings saved" : "已保存後端系統記録伺服器設定",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "主持人將被允許在對話級別啟用同意。 每位參與者在加入此對話中的每個通話之前都需要給予錄製同意。",
    "The consent to be recorded will be required for each participant before joining every call." : "在每次通話之前，每位參與者都需要同意錄製。",
    "The consent to be recorded is not required." : "並不需要獲得錄音同意。",
    "Recording backend configuration is only possible with a High-performance backend." : "僅當使用高效能後端時才能設定錄製後端。",
    "Add a new recording backend server" : "添加新後端系統記録伺服器",
    "Shared secret" : "分享了密碼",
    "Recording consent" : "錄製同意",
    "Recording transcription" : "錄音轉錄",
    "Automatically transcribe call recordings with a transcription provider" : "使用轉錄提供者自動轉錄通話錄音",
    "Automatically summarize call recordings with transcription and summary providers" : "使用轉錄與摘要提供者自動總結通話錄音",
    "SIP configuration saved!" : "已保存 SIP 配置!",
    "SIP configuration is only possible with a High-performance backend." : "SIP 組態僅於有高效能後端時可用。",
    "Enable SIP Dial-out option" : "啟用 SIP 撥出選項",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Signaling 伺服器必須更新以支援 SIP 撥出功能。",
    "Do not show SIP Dial-out caller number" : "不要顯示 SIP Dial-out 來電者號碼。",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "匿名號碼應顯示為「未知號碼」或「隱藏號碼」給接聽者。",
    "Dial-out number" : "Dial-out 電話號碼",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "以 E164 格式顯示的號碼用作外撥電話的備用來電號碼",
    "Dial-out prefix" : "Dial-out 前綴",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "外撥電話時，配置用戶號碼的前綴（默認為 `+`）",
    "Restrict SIP configuration" : "限制SIP配置",
    "Enable SIP configuration" : "啟用 SIP 配置",
    "Only users of the following groups can enable SIP in conversations they moderate" : "只有以下群組的用戶才能在他們主持的對話中啟用SIP",
    "Phone number (Country)" : "電話號碼（國家）",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "此資訊通過邀請電子郵件發送，並在邊欄中顯示給所有參與者。",
    "Nextcloud base URL" : "Nextcloud 基本 URL",
    "Talk Backend URL" : "Talk 後端系統 URL",
    "WebSocket URL" : "WebSocket URL",
    "Available features" : "可用特點",
    "Error: Websocket connection failed" : "錯誤：Websocket 連接失敗",
    "Error code" : "錯誤代碼",
    "Error message" : "錯誤訊息",
    "Error: Websocket connection failed. Check browser console" : "錯誤：Websocket 連接失敗。請檢查瀏覽器主控台",
    "High-performance backend URL" : "高性能後端 URL",
    "Missing High-performance backend warning hidden" : "隱藏缺少高效能後端的警告",
    "High-performance backend settings saved" : "高性能後端設定已保存",
    "Nextcloud Talk setup not complete" : "未完成 Nextcloud Talk 設定",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "請注意，在沒有高效能後端的情況下，如果通話有 2 位以上的參與者，參與者很可能會遇到連線問題，導致參與者的裝置負載過高。",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "安裝高效能後端，以確保有多位參與者的通話能順暢運作。",
    "Nextcloud portal" : "Nextcloud 入口網站",
    "Quick installation guide" : "快速安裝指南",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "有多位參與者的通話和對話需要高效能後端。如果沒有後端，所有參與者都必須為其他參與者各自上傳自己的視訊，這極有可能造成連線問題，並對參與者的裝置造成高負載。",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "使用 Nextcloud Talk 搭配高效能後端時，強烈建議設定分散式快取。",
    "Add High-performance backend server" : "新增高效能後端伺服器",
    "Warn about connectivity issues in calls with more than 2 participants" : "在參與者超過兩人的通話中發出連接問題的警告",
    "STUN server URL" : "STUN 伺服器 URL",
    "The server address is invalid" : "伺服器地址無效",
    "STUN settings saved" : "STUN 設定已保存",
    "STUN servers" : "STUN 伺服器",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN 伺服器用於確定路由器後面的參與者的公共 IP 地址。",
    "Add a new STUN server" : "添加新 STUN 伺服器",
    "{schema} scheme must be used with a domain" : "{schema} 方案必須與域名一起使用",
    "{option1} and {option2}" : "{option1} 和 {option2}",
    "{option} only" : "僅 {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK：TURN 伺服器返回成功的 ICE 候選者",
    "Error: No working ICE candidates returned by the TURN server" : "錯誤：TURN 伺服器未返回任何有效的 ICE 候選者",
    "Testing whether the TURN server returns ICE candidates" : "測試 TURN 伺服器是否返回 ICE 候選者",
    "TURN server schemes" : "TURN 伺服器方案",
    "TURN server URL" : "TURN 伺服器 URL",
    "TURN server secret" : "TURN 伺服器密鑰",
    "TURN server protocols" : "TURN 伺服器協定",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN 伺服器用於代理（proxy）來自防火牆後參與者的流量。如果個別參與者無法連接到其他參與者，則很可能需要 TURN 伺服器。有關設置說明，請參見{linkstart}此說明書{linkend}。",
    "TURN settings saved" : "TURN 設定已保存",
    "TURN servers" : "TURN 伺服器",
    "Add a new TURN server" : "添加新 TURN 伺服器",
    "Failed" : "失敗了",
    "OK" : "OK",
    "Checking …" : "檢查中 ...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "失敗： 此瀏覽器中禁用或不支持 WebAssembly。請啟用 WebAssembly 或使用支持它的瀏覽器進行檢查。",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "失敗：Web 伺服器沒有正確返回 ”.wasm” 和 “.tflite” 檔案。請查看 Talk 說明書中的“系統需求”部分。",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK：Web 伺服器正確返回了 “.wasm” 和 “.tflite” 檔案。",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "似乎 PHP 和 Apache 配置不兼容。 請注意，PHP 只能與 MPM_PREFORK 模塊一起使用，PHP-FPM 只能與 MPM_EVENT 模塊一起使用。",
    "Web server setup checks" : "Web 伺服器設置檢查",
    "Files required for virtual background can be loaded" : "可以加載虛擬背景所需的檔案",
    "Federated user" : "聯盟用戶",
    "Assign participants to rooms" : "將參與者分配到分組討論室",
    "Configure breakout rooms" : "配置分組討論室",
    "Number of breakout rooms" : "分組討論室數量︰",
    "You can create from 1 to 20 breakout rooms." : "您可以建立 1 到 20 個分組討論室。",
    "Assignment method" : "指派方法",
    "Automatically assign participants" : "自動分配參與者",
    "Manually assign participants" : "人手分配參與者",
    "Allow participants to choose" : "允許參與者選擇",
    "Create rooms" : "創建分組討論室",
    "Confirm" : "確認",
    "Create breakout rooms" : "創建分組討論室",
    "Reset" : "重設",
    "Delete breakout rooms" : "刪除分組討論室",
    "Room {roomNumber}" : "聊天室 {roomNumber}",
    "Current breakout rooms and settings will be lost" : "目前的分組討論室和設置將會丟失",
    "Cancel" : "取消",
    "Unassigned participants" : "已取消分配參與者",
    "Back" : "返回",
    "Assign" : "指派",
    "Add participant \"{user}\"" : "添加參與者 \"{user}\"",
    "Now" : "現在",
    "Invalid calendar selected" : "所選的日曆無效",
    "Invalid start time selected" : "所選的開始時間無效",
    "Invalid end time selected" : "所選的結束時間無效",
    "Unknown error occurred" : "發生了不詳的錯誤",
    "Sending no invitations" : "不發送邀請",
    "{participant0} will receive an invitation" : "{participant0} 將會收到邀請",
    "{participant0} and {participant1} will receive invitations" : "{participant0} 與 {participant1} 將會收到邀請",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}、{participant1} 與 %n 個其他人將會收到邀請"],
    "Invite {user}" : "邀請 {user}",
    "Invite all users and emails in this conversation" : "邀請此對話中的所有使用者與電子郵件",
    "Meeting created" : "創建了會議",
    "Upcoming meetings" : "接下來的會議",
    "Loading …" : "加載中 …",
    "No upcoming meetings" : "沒有即將舉行的會議",
    "Schedule a meeting" : "預先安排會議",
    "Meeting title" : "會議標題",
    "From" : "從",
    "To" : "至",
    "Calendar" : "日曆",
    "Attendees" : "參與者",
    "No other participants to send invitations to." : "沒有其他要傳送邀請函的參與者。",
    "Add attendees" : "添加與會者",
    "Save" : "儲存",
    "Search participants" : "搜尋參與者",
    "No results" : "沒有符合搜尋的項目",
    "Done" : "完成",
    "Disable live transcription" : "停用即時轉錄",
    "Enable live transcription (generated by AI)" : "啟用即時轉錄（由人工智能產生）",
    "Enable live transcription (Live transcriptions app is not installed)" : "啟用即時轉錄（未安裝即時轉錄應用程式）",
    "Disable live translation" : "停用即時翻譯",
    "Enable live translation (generated by AI)" : "啟用即時翻譯（由人工智能產生）",
    "Original language" : "原先的語言",
    "Live translations app is not installed" : "未安裝即時翻譯應用程式",
    "Original language: {languageName}" : "原文語言：{languageName}",
    "Translated language" : "翻譯語言",
    "Translated language: {languageName}" : "翻譯語言：{languageName}",
    "Raise hand" : "舉手",
    "Raise hand (R)" : "舉手（R）",
    "Lower hand" : "放下手",
    "Lower hand (R)" : "放下手（R）",
    "Exit full screen (F)" : "離開全螢幕（F）",
    "Full screen (F)" : "全螢幕（F）",
    "Speaker view" : "演講者視圖",
    "Grid view" : "網格檢視",
    "Error when trying to load the available live transcription languages" : "嘗試加載可用的即時轉錄語言時出錯",
    "Failed to enable live transcription" : "無法啟用轉錄",
    "Failed to enable live translations" : "無法啟用即時翻譯",
    "Failed to disable live translations" : "無法停用即時翻譯",
    "Recording consent is required" : "需要錄製同意",
    "This conversation is read-only" : "對話是唯讀狀態",
    "Conversation not found or not joined" : "找不到或未加入對話",
    "Lobby is still active and you're not a moderator" : "等候室仍然活躍，你不是主持人",
    "Connection failed" : "連線失敗",
    "Reload" : "重新載入",
    "{nickName} raised their hand." : "{nickName} 舉起了手。",
    "A participant raised their hand." : "一位參與者舉起了手。",
    "Collapse stripe" : "收合 stripe",
    "Expand stripe" : "展開 stripe",
    "Previous page of videos" : "視像的上一頁",
    "Next page of videos" : "視像的下一頁",
    "Connecting …" : "連線中...",
    "Calling …" : "連接中...",
    "Waiting for {user} to join the call" : "等待 {user} 加入通話...",
    "Waiting for others to join the call …" : "等待其他人加入通話...",
    "You can invite others in the participant tab of the sidebar" : "您可以在邊欄的“參與者”標籤中邀請其他人",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "您可以在邊欄的“參與者”選項卡中邀請其他人，或分享此連結以邀請其他人！",
    "Share this link to invite others!" : "分享此連結以邀請其他人！",
    "Copy link" : "複製連結",
    "You are not allowed to enable audio" : "你無權啟用音頻",
    "No audio. Click to select device" : "沒有音頻。請點擊以選擇裝置",
    "Mute audio" : "靜音",
    "Mute audio (M)" : "靜音（M）",
    "Unmute audio" : "取消靜音",
    "Unmute audio (M)" : "取消靜音（M）",
    "None" : "無",
    "Select a microphone" : "選擇米高風",
    "Select a speaker" : "選擇喇叭",
    "Microphone settings" : "咪高風設定",
    "Check devices" : "檢查裝置",
    "Access to camera was denied" : "無法存取相機",
    "Error while accessing camera: It is likely in use by another program" : "存取相機時出錯：另一個程序可能正在使用鏡頭",
    "Error while accessing camera" : "存取相機時發生錯誤",
    "You have been muted by a moderator" : "您已被主持人靜音",
    "Hide presenter video" : "隱藏演講者視訊",
    "You are not allowed to enable video" : "你無權啟用視像",
    "No video. Click to select device" : "沒有視像。請點擊以選擇裝置",
    "Disable video" : "停用視訊",
    "Disable video (V)" : "停用視像（V）",
    "Enable video" : "啟用視訊",
    "Enable video (V)" : "啟用視訊（V）",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "啟用視像 - 首次啟用視像時，您的連接將短暫中斷",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "啟用視像（V）- 首次啟用視像時，您的連接將短暫中斷",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "啟用視像。首次啟用視像時，您的連接將短暫中斷",
    "Select a video device" : "選擇視訊裝置",
    "Show presenter" : "顯示演講者",
    "You" : "您",
    "Mute" : "無聲",
    "Muted" : "靜音",
    "Show screen" : "顯示螢幕",
    "Stop following" : "停止關注",
    "Connection could not be established …" : "無法建立連線 ...",
    "Connection was lost and could not be re-established …" : "連接被切斷，無法重新建立 …",
    "Connection could not be established. Trying again …" : "無法建立連接。 再試一次 …",
    "Connection lost. Trying to reconnect …" : "連接切斷。 正在嘗試重新連接…",
    "Connection problems …" : "連接問題 …",
    "Collapse" : "收合",
    "Expand" : "展開",
    "You need to be logged in to upload files" : "您需要登入才能上傳檔案",
    "Drop your files to upload" : "拖放您的檔案以上傳",
    "Conversation messages" : "對話訊息",
    "Scroll to bottom" : "滾動到底部",
    "Post message" : "發表訊息",
    "Federated conversation" : "聯合對話",
    "Public conversation" : "公開對話",
    "Favorite" : "我的最愛",
    "Banned users" : "被封禁的用戶",
    "Manage the list of banned users in this conversation." : "管理此對話中被封禁用戶的清單。",
    "Manage bans" : "管理封禁",
    "No banned users" : "沒有被封禁的用戶",
    "Banned by:" : "封鎖者：",
    "Date:" : "日期：",
    "Note:" : "備註：",
    "Hide details" : "隱藏細節",
    "Show details" : "顯示細節",
    "Unban" : "解除封禁",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "您可以在{linkstart}日曆 ↗{linkend}中變更標題與描述。",
    "Error while updating conversation name" : "更新對話名稱時發生錯誤",
    "Error while updating conversation description" : "更新對話描述時發生錯誤",
    "Enter a name for this conversation" : "輸入此對話名稱",
    "Edit conversation name" : "編輯對話名稱",
    "Edit conversation description" : "編輯對話描述",
    "Enter a description for this conversation" : "輸入此對話的描述",
    "Picture" : "圖片",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "可在此對話啟用以下機器人。請與您的管理員聯絡以在此伺服器上安裝更多機器人。",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "此伺服器上未安裝機器人。請與您的管理員聯絡以在此伺服器上安裝機器人。",
    "Disable" : "停用",
    "Enable" : "啟用",
    "The bot is not available anymore" : "該機器人已不再提供服務",
    "Breakout rooms" : "分組討論室",
    "Manage breakout rooms" : "管理分組討論室",
    "Set up breakout rooms for this conversation" : "在此對話中設置分組討論室",
    "Please select a valid PNG or JPG file" : "請選擇有效的 PNG 或 JPG 檔案",
    "Choose your conversation picture" : "選擇您的對話圖片",
    "Choose" : "選擇",
    "Error setting conversation picture" : "設定對話圖片時出錯",
    "Could not set the conversation picture: {error}" : "無法設置對話圖片： {error}",
    "Error cropping conversation picture" : "裁剪對話圖片時出錯",
    "Error removing conversation picture" : "移除對話圖片時出錯",
    "Set emoji as conversation picture" : "設定 emoji 為對話圖片",
    "Set background color for conversation picture" : "設置對話圖片的背景顏色",
    "Upload conversation picture" : "上傳對話圖片",
    "Choose conversation picture from files" : "從檔案選擇對話圖片",
    "Remove conversation picture" : "移除對話圖片",
    "The file must be a PNG or JPG" : "該檔案必須是 PNG 或 JPG",
    "Set picture" : "設置圖片",
    "Default permissions modified for {conversationName}" : "為 {conversationName} 修改了默認權限",
    "Could not modify default permissions for {conversationName}" : "無法更改 {conversationName} 的權限",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "編輯此對話中參與者的默認權限。 這些設置不會影響主持人。",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "每次在此部分修改權限時，之前分配給各個參與者的自訂權限都將丟失。",
    "All permissions" : "所有權限",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "參與者有權發起通話、加入通話、啟用音頻、視像和螢幕共享。",
    "Participants can use all available features." : "參與者可以使用所有可用的功能。",
    "Restricted" : "受限",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "在主持人手動授予他們權限之前，參與者只能加入對話，但不能啟用音頻、視頻或螢幕共享。",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "參與者在管理員手動授予額外權限前，只能使用受限的功能。",
    "Advanced permissions" : "高級權限",
    "Edit permissions" : "編輯權限",
    "Conversation settings" : "對話設定",
    "Basic Info" : "基本資料",
    "Personal" : "個人",
    "Moderation" : "主持",
    "Setup overview" : "設置概覽",
    "Live transcription" : "即時轉錄",
    "Live transcriptions app is not installed" : "未安裝即時轉錄應用程式",
    "Enable live transcription" : "啟用即時轉錄",
    "Breakout Rooms" : "分組討論室",
    "Matterbridge" : "Matterbridge",
    "Bots" : "機器人",
    "Danger zone" : "危險地帶",
    "Archive conversation" : "封存對話",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "預設情況下，已封存的對話會從對話清單中隱藏。但是，當您搜尋對話名稱或存取已封存的對話清單時，它們仍會出現。",
    "Do you really want to leave \"{displayName}\"?" : "您真的想要離開「{displayName}」嗎？",
    "You can archive this conversation instead." : "您可以改為封存此對話。",
    "Leave conversation" : "離開對話",
    "You need to promote a new moderator before you can leave the conversation" : "在您離開對話之前您需要推舉一位新的主持人",
    "Delete conversation" : "刪除對話",
    "Do you really want to delete \"{displayName}\"?" : "您確定要刪除\"{displayName}\"嗎？",
    "Error while deleting conversation" : "刪除對話時發生錯誤",
    "Delete all chat messages" : "刪除所有聊天訊息",
    "Do you really want to delete all messages in \"{displayName}\"?" : "您確定要刪除 \"{displayName}\" 內所有的訊息嗎？",
    "Error while clearing chat history" : "清除聊天記錄時出錯",
    "Be careful, these actions cannot be undone." : "請注意，這些操作無法還原。",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "離開封閉式對話後，您需要收到邀請才能重新加入。 您可以隨時重新加入公開對話。",
    "Permanently delete this conversation." : "永久刪除此對話。",
    "Delete chat messages" : "刪除聊天訊息",
    "Permanently delete all the messages in this conversation." : "永久刪除此對話中的所有訊息。",
    "_%n hour_::_%n hours_" : ["%n 小時"],
    "_%n day_::_%n days_" : ["%n 天"],
    "_%n week_::_%n weeks_" : ["%n個星期"],
    "Custom expiration time" : "自訂定到期日",
    "Message expiration disabled" : "訊息過期功能已禁用",
    "Message expiration set: {duration}" : "訊息過期設置：{duration}",
    "Error when trying to set message expiration" : "嘗試設置訊息過期時出錯",
    "Message expiration" : "訊息過期",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "聊天訊息可能會在一定時間後過期。注意：在聊天中共享的檔案不會為所有者刪除，但將不再在對話中共享。",
    "Set message expiration" : "設置訊息過期時間",
    "Current message expiration" : "目前的訊息過期時間",
    "Password copied to clipboard" : "密碼已複製到剪貼板",
    "Password could not be copied" : "密碼無法複製",
    "Guest access" : "訪客存取",
    "Breakout rooms are not allowed in public conversations." : "公共對話中不允許分組討論。",
    "Allow guests to join this conversation via link" : "允許訪客透過連結加入此對話",
    "Password protection" : "密碼保護",
    "This conversation is password-protected. Guests need password to join" : "此對話受到密碼保護。訪客需要密碼才能加入。",
    "Password protection is needed for public conversations" : "公共對話需要密碼保護。",
    "Set a password" : "設定密碼",
    "Change password" : "更改密碼",
    "Enter new password" : "輸入新密碼",
    "Save password" : "保存密碼",
    "Copy password" : "複製密碼",
    "Guests are allowed to join this conversation via link" : "允許訪客透過連結加入此對話",
    "Guests are not allowed to join this conversation" : "不允許訪客透過連結加入此對話",
    "Resend invitations" : "重新傳送邀請",
    "This conversation is open to both registered users and users created with the Guests app" : "此對話已同時對已註冊的用戶及使以訪客(Guests)應用程式建立的用戶開放",
    "This conversation is open to registered users" : "此對話對已註冊的用戶開放",
    "This conversation is limited to the current participants" : "此對話僅限目前參與者",
    "You opened the conversation to both registered users and users created with the Guests app" : "您同時向已註冊用戶及以訪客(Guests)應用程式建立的用戶開放了對話",
    "Error occurred when opening or limiting the conversation" : "打開或限制對話時發生錯誤",
    "Open conversation to registered users, showing it in search results" : "向註冊用戶開放對話並在搜索結果中顯示",
    "Also open to users created with the Guests app" : "同時對以訪客(Guests)應用程式建立的用戶開放",
    "Open conversation" : "開放對話",
    "Set language spoken in calls" : "設置通話語言",
    "Languages could not be loaded" : "無法加載語言",
    "Loading languages …" : "正在載入語言 …",
    "Invalid language" : "無效的語言",
    "Default language (English)" : "默認語言 (英文)",
    "Default live transcription language set" : "默認即時轉錄語言集",
    "Live transcription language set: {languageName}" : "即時轉錄語言集: {languageName}",
    "Error when trying to set live transcription language" : "嘗試設置即時轉錄語言時出錯",
    "Start time: {date}" : "開始時間：{date}",
    "Start time has been updated" : "開始時間已被更新。",
    "Error occurred while updating start time" : "更新開始時間時發生錯誤",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "啟用等候室將從正在進行的通話中刪除非主持人。",
    "Enable lobby, restricting the conversation to moderators" : "啟用等候室，將對話限制為主持人",
    "Meeting start time" : "會議開始時間",
    "Start time (optional)" : "開始時間（可選）",
    "Import email participants" : "匯入電子郵件參與者",
    "You can import a list of email participants from a CSV file." : "您可以從 CSV 檔案匯入電子郵件參與者清單。",
    "Poll drafts" : "民意調查草稿",
    "Browse poll drafts" : "瀏覽民意調查草稿",
    "Error occurred when locking the conversation" : "上鎖會話時發生了錯誤",
    "Error occurred when unlocking the conversation" : "解鎖會話時發生了錯誤",
    "Lock conversation" : "鎖定對話",
    "This will also terminate the ongoing call." : "這也將終止正在進行的通話。",
    "Lock the conversation to prevent anyone to post messages or start calls" : "鎖上對話以防止任何人發佈消息或發起對話。",
    "Edit" : "編輯",
    "More information" : "更多資訊",
    "Delete" : "刪除",
    "Add new bridged channel to current conversation" : "添加新的橋接頻道至對話",
    "unknown state" : "狀態不詳",
    "running" : "運行中",
    "not running, check Matterbridge log" : "未運行，請檢查Matterbridge日誌",
    "not running" : "沒有運行",
    "Bridge saved" : "Bridge 已保存",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "您可以使用 Matterbridge 橋接來自各種即時消息傳遞系統的頻道。",
    "More info on Matterbridge" : "有關 Matterbridge 的更多信息。",
    "Messaging systems" : "訊息系統",
    "Enable bridge" : "啟用 bridge",
    "Show Matterbridge log" : "顯示 Matterbridge 記錄",
    "Log content" : "記錄內容",
    "Only moderators are allowed to mention @all" : "僅允許主持人提及 @all",
    "All participants are allowed to mention @all" : "僅允所有參與者提及 @all",
    "Participants are now allowed to mention @all." : "現在參與者可以提及 @all。",
    "Mentioning @all has been limited to moderators." : "提及 @all 的權限已限於主持人。",
    "Allow participants to mention @all" : "允許參與者提及 @all",
    "Mention permissions" : "提及權限",
    "Notifications" : "通告",
    "Notify about calls in this conversation" : "在此對話中有電話時通知",
    "Important conversation" : "重要對話",
    "\"Do not disturb\" user status is ignored for important conversations" : "「勿擾」用戶狀態將在重要對話中略過。",
    "Sensitive conversation" : "敏感對話",
    "Message preview will be disabled in conversation list and notifications" : "對話清單和通知中的訊息預覽將被停用。",
    "Recording consent is required for calls in this conversation" : "在此次對話中，需要獲得錄製同意",
    "Recording consent is not required for calls in this conversation" : "在此次通話中，並不需要獲得錄製同意",
    "Recording consent requirement was updated" : "錄製同意需求已更新",
    "Error occurred while updating recording consent" : "更新錄製同意時發生錯誤",
    "Recording Consent" : "錄製同意",
    "Recording consent cannot be changed once a call or breakout session has started." : "通話或分組會議開始後，錄製同意就無法更改。",
    "Require recording consent before joining call in this conversation" : "在此次對話中，需要在加入通話前給予錄製同意",
    "Recording consent is required for all calls" : "所有通話都需要獲得錄製同意",
    "SIP dial-in is now possible without PIN requirement" : "SIP 撥入現在無需密碼",
    "SIP dial-in is now enabled" : "現在啟用了 SIP 撥入",
    "SIP dial-in is now disabled" : "已停用 SIP 撥入功能",
    "Error occurred when enabling SIP dial-in" : "啟用SIP撥入時發生錯誤",
    "Error occurred when disabling SIP dial-in" : "停用SIP撥入時發生錯誤",
    "Phone and SIP dial-in" : "電話及 SIP 撥入",
    "Enable phone and SIP dial-in" : "啟用電話及 SIP 撥入",
    "Allow to dial-in without a PIN" : "允許在沒有密碼的情況下撥入",
    "Ongoing" : "持續進行",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["已接受 %n 個人"],
    "_%n person declined_::_%n people declined_" : ["已拒絕 %n 個人"],
    "_and %n other attachment_::_and %n other attachments_" : ["及 %n 其他附件"],
    "With {displayName}" : "與 {displayName}",
    "In {conversation}" : "在 {conversation} 對話中",
    "View attachment" : "檢視附件",
    "Join" : "加入",
    "View conversation" : "檢視對話",
    "View event on Calendar" : "在日曆上檢視活動",
    "Error while creating the conversation" : "建立會話時發生了錯誤",
    "Hello, {displayName}" : "哈囉，{displayName}",
    "Start meeting now" : "立刻開始會議",
    "Give your meeting a title" : "為您的會議命名",
    "Create and copy link" : "建立並複製連結",
    "Create a new conversation" : "創建新對話",
    "Join open conversations" : "加入公開對話",
    "Call a phone number" : "撥打電話號碼",
    "Scroll backward" : "向後捲動",
    "Scroll forward" : "向前捲動",
    "Schedule meetings" : "安排會議",
    "You don't have any upcoming meetings" : "您沒有任何即將舉行的會議",
    "Calendar events with a conversation link as the location are shown here" : "以對話連結作為地點的日曆活動會在此顯示",
    "Open calendar" : "打開日曆",
    "Unread mentions" : "未讀的提及",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "提及您的訊息將顯示於此處。您可以透過輸入 @ 加上對方姓名來標記他人。",
    "Upcoming reminders" : "即將到來的提醒",
    "Message reminders" : "訊息提醒",
    "Set a reminder on a message to be notified" : "在訊息上設定提醒以接收通知",
    "Start a group conversation" : "開始群組對話",
    "Create conversation" : "建立對話",
    "Enter your name" : "輸入您的名稱",
    "Submit name and join" : "遞交名稱並加入",
    "Do you already have an account?" : "您已經有帳戶了嗎？",
    "Log in" : "登入",
    "Error while verifying uploaded file" : "驗證上傳的檔案時發生錯誤",
    "Uploaded file is verified" : "已驗證上傳的檔案",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "內容格式為逗號分隔值 (CSV)：<br/>- 標題行為必填，且必須符合 <samp>\"名字\",\"電郵地址\"</samp> 或 <samp>\"電郵地址\"</samp><br/>- 一個項目一行（例如 <samp>\"John Doe\",\"john@example.tld\"</samp>）",
    "Participants added successfully" : "參與者新增成功",
    "Error while adding participants" : "新增參與者時發生錯誤",
    "Import a file" : "導入檔案",
    "Browse" : "瀏覽",
    "Verifying uploaded file …" : "正在驗證已上傳的檔案 …",
    "This might take a moment" : "這可能需要一段時間",
    "Send invitations" : "傳送邀請",
    "_%n invalid email_::_%n invalid emails_" : ["%n 個無效的電郵地址"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["有 %n 個電郵地址已導入或重複"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["可以傳送 %n 個邀請"],
    "An error occurred while calling a phone number" : "撥打電話號碼時發生錯誤",
    "Phone number could not be called: {error}" : "無法撥打電話號碼：{error}",
    "Phone number could not be called" : "無法撥打電話號碼",
    "Search participants or phone numbers" : "搜尋參與者或電話號碼",
    "Creating the conversation …" : "正在建立對話 ...",
    "Mark as read" : "標為已讀",
    "Mark as unread" : "標為未讀",
    "Remove from favorites" : "取消我的最愛",
    "Add to favorites" : "加到我的最愛",
    "Unarchive conversation" : "解除封存對話",
    "Ignore \"Do not disturb\"" : "不用理會「請勿打擾」",
    "You need to promote a new moderator before you can leave the conversation." : "在您離開對話之前您需要推舉一位新的主持人。",
    "Conversation actions" : "對話操作",
    "Notify about calls" : "通話通知",
    "Hide message text" : "隱藏訊息文字",
    "Pending invitations" : "擱置中的邀請",
    "Join conversations from other servers" : "加入其他伺服器的對話",
    "From {user} at {remoteServer}" : "來自 {remoteServer} 的 {user}",
    "Decline invitation" : "婉拒邀請",
    "Accept invitation" : "接受邀請",
    "No pending invitations" : "沒有待處理的邀請",
    "Home" : "主頁",
    "Unread" : "未讀",
    "Mentions" : "提及",
    "Meetings" : "會議",
    "Sort conversations" : "排序對話",
    "By recent activity" : "按最近活動排序",
    "Alphabetically" : "按字母順序",
    "Do not group by type" : "請勿按類型分組",
    "Show private ones first" : "先顯示私人訊息",
    "Show group ones first" : "先顯示群組訊息",
    "No followed threads" : "沒有追蹤的討論串",
    "No matches found" : "找不到符合的項目",
    "No conversations found" : "找不到對話",
    "You have no archived conversations." : "您沒有已封存的對話。",
    "Subscribe to an existing thread or start your own." : "訂閱既有的討論串或開啟您的討論串。",
    "You have no unread mentions." : "您沒有未讀的提及。",
    "You have no unread messages." : "您沒有未讀的訊息。",
    "An error occurred while performing the search" : "搜尋時發生了錯誤",
    "Conversation list" : "對話清單",
    "Filter conversations by" : "按以下條件過濾對話",
    "Unread messages" : "未讀郵件",
    "Meeting conversations" : "會議對話",
    "Clear filters" : "清除過濾器",
    "New personal note" : "新個人筆記",
    "SIP backend is not installed" : "未安裝 SIP 後端",
    "Back to conversations" : "回到對話",
    "Archived conversations" : "已封存的對話",
    "Threads" : "討論串",
    "Clear filter" : "清空過濾器",
    "Show more threads" : "顯示更多討論串",
    "App settings" : "應用程式設定",
    "Users" : "用戶",
    "Groups" : "群組",
    "Teams" : "團隊",
    "Federated users" : "聯盟用戶",
    "New private conversation" : "新私人對話",
    "Other sources" : "其他來源",
    "Open conversations" : "開放對話",
    "No search results" : "無搜尋結果",
    "Users, groups and teams" : "用戶，群組和團隊",
    "Users and groups" : "用戶和群組",
    "Users and teams" : "用戶和團隊",
    "Groups and teams" : "群組和團隊",
    "New group conversation" : "新群組對話",
    "The meeting will start soon" : "會議即將開始",
    "This meeting is scheduled for {startTime}" : "此會議定於 {startTime} 開始",
    "You are currently waiting in the lobby" : "您目前正在等候室等候。",
    "Enable noise suppression" : "啟用降噪",
    "Reduce background noises for better voice quality" : "減少背景噪音，以提升語音品質",
    "Enable echo cancellation" : "啟用回音消除",
    "Minimize echo effect from own surrounding" : "降低周圍環境造成的回音效果",
    "Enable auto gain control" : "啟用自動增益控制",
    "Dynamically adjust microphone volume for consistent level" : "動態調整咪高風音量，以保持音量一致",
    "Select microphone" : "選擇米高風",
    "No microphone available" : "沒有可用的米高風",
    "Select speaker" : "選擇喇叭",
    "No speaker available" : "沒有可用的喇叭",
    "Select camera" : "選擇相機",
    "No camera available" : "沒有可用的相機",
    "Select a device" : "選取裝置",
    "Playing …" : "正在播放 …",
    "Test speakers" : "測試喇叭",
    "Test" : "測試",
    "Devices" : "裝置",
    "Backgrounds" : "背景",
    "No audio" : "沒有音訊",
    "No camera" : "沒有相機",
    "Display video as you will see it (mirrored)" : "顯示您將看到的視訊（鏡像）",
    "Display video as others will see it" : "以其他人看到的方式顯示視訊",
    "Calls are not supported in your browser" : "你使用的瀏覽器不支援通話",
    "Access to microphone is only possible with HTTPS" : "只有使用 HTTPS 才能存取米高風",
    "Access to microphone was denied" : "存取米高風被拒絕",
    "Error while accessing microphone" : "存取米高風時發生錯誤",
    "Access to camera is only possible with HTTPS" : "只有使用 HTTPS 才能存取相機",
    "The call is being recorded." : "通話正在錄音中。",
    "The call might be recorded." : "通話可能會被錄製。",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "錄製可能包括您的聲音、視像和螢幕共享。在您加入通話之前，需要獲得您的同意。",
    "Give consent to the recording of this call" : "請您同意錄製此通話",
    "Show more info" : "顯示更多資訊",
    "Audio is not available" : "音頻不可用",
    "Video is not available" : "視像不可用",
    "Start recording immediately with the call" : "通話後立刻開始錄音",
    "Recording backend is not installed" : "未安裝錄製後端",
    "Notify all participants about this call" : "通知所有參與者此通話",
    "Apply settings" : "運用設定",
    "Select virtual office background" : "選擇虛擬辦公室背景",
    "Select virtual home background" : "選擇虛擬家居背景",
    "Select virtual abstract background" : "選擇虛擬抽象背景",
    "Select virtual beach background" : "選擇虛擬海灘背景",
    "Select virtual park background" : "選擇虛擬公園背景",
    "Select virtual theater background" : "選擇虛擬劇院背景",
    "Select virtual library background" : "選擇虛擬圖書館背景",
    "Select virtual space station background" : "選擇虛擬太空站背景",
    "Error while uploading the file" : "上傳檔案時發生錯誤",
    "Select a file" : "選擇檔案",
    "Invalid path selected" : "所選的路徑無效",
    "Select virtual background from file {fileName}" : "從檔案 {fileName} 選擇虛擬背景",
    "Blur" : "模糊",
    "Upload" : "上傳",
    "Files" : "檔案",
    "(editing)" : "（正在編輯）",
    "(edited)" : "（已編輯）",
    "The message has expired or has been deleted" : "訊息已過期或已被刪除。",
    "Cancel quote" : "取消報價",
    "24 hours" : "24 小時",
    "7 days" : "7 日",
    "30 days" : "30 日",
    "Until unpin" : "直到取消置頂",
    "Clear reminder – {timeLocale}" : "清除提醒 – {timeLocale}",
    "Edited by {actor}" : "由 {actor} 編輯",
    "Pinned by you" : "由你置頂",
    "Pinned by {actor}" : "由 {actor} 置頂",
    "Until {absoluteDate}" : "直到 {absoluteDate}",
    "Message text copied to clipboard" : "訊息文字已複製到剪貼板",
    "Message text could not be copied" : "訊息文字無法複製",
    "Message forwarded to \"Note to self\"" : "訊息已轉寄至「給自己的註記」",
    "Error while forwarding message to \"Note to self\"" : "轉寄訊息到「給自己的註記」時發生錯誤",
    "A reminder was successfully removed" : "已成功移除提醒",
    "Error occurred when removing a reminder" : "移除提醒時發生錯誤",
    "A reminder was successfully set at {datetime}" : "已成功設定於 {datetime} 的提醒",
    "Error occurred when creating a reminder" : "建立提醒時發生錯誤",
    "Add a reaction to this message" : "添加對此訊息的反應",
    "Reply" : "回覆",
    "More actions" : "更多操作",
    "Set reminder" : "設定提醒",
    "Pin message" : "置頂訊息",
    "Unpin message" : "取消置頂訊息",
    "Reply privately" : "私下回覆",
    "Edit message" : "編輯訊息",
    "Copy message" : "複製訊息",
    "Copy message link" : "複製訊息連結",
    "Go to file" : "前往檔案",
    "Download file" : "下載檔案",
    "Go to thread" : "前往討論串",
    "Edit thread details" : "編輯討論串詳細資訊",
    "Forward message" : "轉寄訊息",
    "Translate" : "翻譯",
    "Set custom reminder" : "設定自訂提醒",
    "Keep pinned for" : "置頂保留期限",
    "Set custom period" : "設定自訂期限",
    "Close reactions menu" : "關閉反應選項單",
    "React with {emoji}" : "使用 {emoji} 做出反應",
    "React with another emoji" : "使用另一個表情符號做出反應",
    "Choose a conversation to forward the selected message." : "選擇要將所選消息轉發到的對話。",
    "Error while forwarding message" : "轉寄訊息時發生錯誤",
    "The message has been forwarded to {selectedConversationName}" : "訊息已轉發至 {selectedConversationName}",
    "Dismiss" : "撤銷",
    "Go to conversation" : "前往對話",
    "Detect language" : "檢測語言",
    "The message could not be translated" : "無法翻譯訊息",
    "Translation copied to clipboard" : "翻譯已複製到剪貼簿",
    "Translation could not be copied" : "無法複製翻譯",
    "Translate message" : "翻譯訊息",
    "Source language to translate from" : "要翻譯的來源語言",
    "Translate from" : "翻譯從",
    "Target language to translate into" : "要翻譯至的目標語言",
    "Translate to" : "翻譯至",
    "Translating" : "正在翻譯",
    "This translation is AI generated and may contain mistakes." : "此翻譯為人工智能產生，可能會出錯。",
    "Copy translated text" : "複製已翻譯的文字",
    "Error when scheduling the message" : "安排傳送訊息時發生錯誤",
    "Reschedule" : "重新安排",
    "Send now" : "立即傳送",
    "Choose a time" : "選擇時間",
    "Send at custom time" : "於自訂時間傳送",
    "Will be sent without notification" : "將不另行發出傳送檔案通知",
    "Message read by everyone who shares their reading status" : "共享閱讀狀態的所有人都閱讀了該郵件",
    "Message sent" : "訊息已傳送",
    "Sent without notification" : "傳送而不通知",
    "Deleting message" : "正在刪除訊息",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "訊息已成功刪除，但已設定機器人或 Matterbridge，訊息可能已散佈至其他服務",
    "Message deleted successfully" : "成功刪除了訊息",
    "Message could not be deleted because it is too old" : "無法刪除訊息，因為它距今太久",
    "Only normal chat messages can be deleted" : "只能刪除普通聊天訊息",
    "An error occurred while deleting the message" : "刪除訊息時發生錯誤",
    "Pinned" : "已置頂",
    "Your browser does not support playing audio files" : "您的瀏覽器不支援播放音頻檔案",
    "Contact" : "聯絡人",
    "{stack} in {board}" : "{board} 中的 {stack}",
    "Deck Card" : "看板卡片",
    "Remove {fileName}" : "移除 {fileName}",
    "Open this location in OpenStreetMap" : "在 OpenStreetMap 中打開此位置",
    "_%n reply_::_%n replies_" : ["%n 個回覆"],
    "Sending message" : "傳送訊息",
    "Failed to send the message. Click to try again" : "發送消息失敗。點擊重試",
    "Not enough free space to upload file" : "空間不足，不能上傳檔案",
    "You cannot send messages to this conversation at the moment" : "您目前無法向此對話發送消息",
    "Could not update the message" : "無法更新訊息",
    "Reply to thread \"{threadTitle}\"" : "回覆討論串「{threadTitle}」",
    "_You voted • %n vote_::_You voted • %n votes_" : ["您已投票 • %n 票"],
    "You voted" : "您已投票",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["點選以投票 • %n 票"],
    "Click to vote" : "點選以投票",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["民意調查草稿 • %n 選項"],
    "_%n vote_::_%n votes_" : ["%n 張選票"],
    "Edit poll draft" : "編輯民意調查草稿",
    "Delete poll draft" : "刪除民意調查草稿",
    "Open poll" : "開放投票",
    "Closed poll" : "已關閉的投票",
    "See results" : "查看結果",
    "Reactions" : "反應",
    "No permission to post reactions in this conversation" : "無權在此對話中發表反應",
    "and {participant}" : "及 {participant}",
    "_and %n other participant_::_and %n other participants_" : ["及 %n 其他參與者"],
    "Show all reactions" : "顯示所有反應",
    "Add more reactions" : "添加更多反應",
    "Show or collapse system messages" : "顯示或折疊系統訊息",
    "No messages" : "沒有訊息",
    "All messages have expired or have been deleted." : "所有訊息都已過期或已被刪除。",
    "Generate summary with AI" : "使用人工人工智能產生摘要",
    "{author} (pinned by you)" : "{author}（由你置頂）",
    "{author} (pinned by {actor})" : "{author}（由 {actor} 置頂）",
    "Unpin" : "取消固定",
    "Cancel search" : "取消搜尋",
    "Add a phone number" : "添加電話號碼",
    "Error: A password is required to create the conversation." : "錯誤：創建對話需要密碼。",
    "All set, the conversation \"{conversationName}\" was created." : "一切就緒，對話 「{conversationName}」已創建。",
    "Create a new group conversation" : "建立新群組對話",
    "Add participants" : "添加參與者",
    "Maximum length exceeded ({maxlength} characters)" : "超出最大長度（{maxlength} 個字元）",
    "Conversation type" : "對話類型",
    "Conversation visibility" : "對話可見性",
    "Allow guests to join via link" : "允許訪客透過連結加入",
    "Enter password" : "輸入密碼",
    "This conversation has been locked" : "此對話已被上鎖",
    "No permission to post messages in this conversation" : "無權在此對話中發佈訊息",
    "Joining conversation …" : "正在加入對話 …",
    "Write a message without notification" : "撰寫訊息而不通知",
    "Create a thread silently" : "默默建立討論串",
    "Create a thread" : "創建討論串",
    "Send message silently" : "無聲傳送訊息",
    "Send message" : "傳送訊息",
    "Send without notification" : "傳送而不通知",
    "The participant will not be notified about new messages" : "參與者將不會收到新訊息通知",
    "Participants will not be notified about new messages" : "參與者將不會收到新訊息通知",
    "Message will be sent {datetimeString}" : "訊息將於 {datetimeString} 傳送",
    "Thread title is required" : "討論串標題為必填",
    "Message text is required" : "訊息文字為必填",
    "The message could not be edited" : "無法編輯訊息",
    "File to share" : "要分享的檔案",
    "File upload is not available in this conversation" : "此對話中無法上傳檔案",
    "Message was successfully scheduled" : "訊息已成功安排傳送",
    "Add emoji" : "添加 emoji",
    "Adding a mention will only notify users who did not read the message." : "添加提及只會通知尚未閱讀訊息的用戶。",
    "Thread title" : "討論串標題",
    "Send later" : "稍後傳送",
    "Show scheduled messages" : "顯示已安排傳送的訊息",
    "Cancel editing" : "取消編輯",
    "Schedule message" : "預先安排訊息",
    "{user} is out of office and might not respond." : "{user} 不在辦公室，可能不會回覆。",
    "Absence period: {startDate} - {endDate}" : "缺席期間：{startDate} - {endDate}",
    "Replacement:" : "取代︰",
    "Share from {nextcloud}" : "透過 {nextcloud} 分享",
    "Share from Files" : "從檔案進行分享",
    "Share files to the conversation" : "在對話中分享檔案",
    "Upload from device" : "從裝置上傳",
    "Create new poll" : "創建新民意調查",
    "Smart picker" : "聰明的選擇器",
    "Record voice message" : "錄製話音短訊",
    "End recording and send" : "結束錄音並傳送",
    "Dismiss recording" : "撤銷錄音",
    "Access to the microphone was denied" : "存取米高風被拒絕",
    "Microphone either not available or disabled in settings" : "麥克風不可用或在設置中停用",
    "Error while recording audio" : "錄音時出錯",
    "Voice message {time} ({conversation})" : "從 {time} 開始的語音訊息（{conversation}）",
    "Generating summary of unread messages …" : "正在産生未讀訊息的摘要 ...",
    "Summary is AI generated and might contain mistakes" : "摘要為人工智能產生，可能有錯",
    "Error occurred during a summary generation" : "在産生摘要過程中發生錯誤",
    "New file" : "新增檔案",
    "Blank" : "空白",
    "Error while creating file" : "建立檔案時發生錯誤",
    "Create and share a new file" : "創建及分享新檔案",
    "Name of the new file" : "新檔案名稱",
    "Create file" : "創建檔案",
    "Someone is typing …" : "有人在打字 …",
    "{user1} is typing …" : "{user1} 在打字……",
    "{user1} and {user2} are typing …" : "{user1} 及 {user2} 在打字 …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}、{user2} 及 {user3} 正在打字 …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}、{user2}、{user3} 及其他 %n 人正在打字 …"],
    "Add more files" : "添加更多檔案",
    "Send" : "傳送",
    "In this conversation <strong>{user}</strong> can:" : "此對話中，<strong>{user}</strong>可以：",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "編輯 <strong>{conversationName}</strong> 中參與者的默認權限",
    "Start a call" : "開始通話",
    "Skip the lobby" : "跳過等候室",
    "Can post messages" : "可以發佈訊息",
    "Can post messages and reactions" : "可以發佈消息和反應",
    "Can add reactions" : "可以添加反應",
    "Enable the microphone" : "啟用米高風",
    "Enable the camera" : "啟用相機",
    "Share the screen" : "分享螢幕",
    "Update permissions" : "更新權限",
    "Updating permissions" : "更新權限",
    "No poll drafts" : "沒有民意調查草稿",
    "There is no poll drafts yet saved for this conversation" : "尚未為此對話保存民意調查草稿",
    "Create poll in {name}" : "在 {name} 建立投票",
    "Create poll" : "創建民意調查",
    "Error while importing poll" : "導入投票時發生錯誤",
    "Question" : "問題",
    "Ask a question" : "問一個問題",
    "Import draft from file" : "從檔案導入草稿",
    "Answers" : "答案",
    "Answer {option}" : "答案 {option}",
    "Delete poll option" : "刪除民意調查選項",
    "Add answer" : "添加答案",
    "Settings" : "設定",
    "Anonymous poll" : "匿名投票",
    "Multiple answers" : "多個答案",
    "Save as draft" : "保存為草稿",
    "Export draft to file" : "將草稿導出至檔案",
    "_Final results • %n vote_::_Final results • %n votes_" : ["最終結果 • %n 票"],
    "Your vote is anonymous" : "您的投票是匿名的",
    "You voted for this option" : "您投了此選項一票",
    "End poll" : "結束民意調查",
    "Change your vote" : "更改您的投票",
    "Withdraw vote" : "撤回投票",
    "Results" : "結果",
    "Voted participants" : "投票參與者",
    "Send a message to \"{roomName}\"" : "向 “{roomName}” 傳送訊息",
    "Hide list of participants" : "隱藏參與者清單",
    "Show list of participants" : "顯示參與者清單",
    "Assistance requested in {roomName}" : "{roomName} 請求協助",
    "The message was sent to \"{roomName}\"" : "訊息已發佈至 “{roomName}”",
    "Dismiss request for assistance" : "撤銷協助請求",
    "Send message to room" : "傳送訊息至聊天室",
    "Back to main room" : "回到主室",
    "Back to your room" : "回到您的聊天室",
    "Message all rooms" : "向所有聊天室發送訊息",
    "Start session" : "開始時段",
    "Start a call before you start a breakout room session" : "在開始分組討論室之前開始通話",
    "Stop session" : "停止時段",
    "The message was sent to all breakout rooms" : "訊息已傳送至所有分組討論室",
    "Send a message to all breakout rooms" : "向所有分組討論室傳送訊息",
    "Breakout rooms are not started" : "分組討論室未啟動",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "沒有高效能後端的通話可能導致連接問題和設備負載過高。{linkstart}了解更多{linkend}",
    "Talk setup incomplete" : "未完成 Talk 設定",
    "Disable lobby" : "等候室停用",
    "Settings for participant \"{user}\"" : "參與者 \"{user}\" 的設定",
    "Participant \"{user}\"" : "參與者 \"{user}\"",
    "moderator" : "主持人",
    "bot" : "機器人",
    "guest" : "訪客",
    "Ringing …" : "連線中 …",
    "Call rejected" : "通话被拒絕",
    "{time} talking …" : "{time} 說話中 ...",
    "{time} talking time" : "{time} 說話時間",
    "Raised their hand" : "舉手",
    "Joined with video" : "用戶已加入視像對話",
    "Joined via phone" : "透過電話加入",
    "Joined with audio" : "用戶已加入音頻對話",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "文字的長度必須小於或等於{maxLength}個字符。您目前的文本長度為{charactersCount}個字符。",
    "Remove group and members" : "移除群組及組員",
    "Remove team and members" : "移除團隊和成員",
    "Remove participant" : "移除參與者",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "你確定要將群組「{displayName}」及其成員從此對話中移除嗎？",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "你確定要將團隊「{displayName}」及其成員從此對話中移除嗎？",
    "Do you really want to remove {displayName} from this conversation?" : "你確定要將「{displayName}」從此對話中移除嗎？",
    "Notification was sent to {displayName}" : "通告已傳送至 {displayName}",
    "Could not send notification to {displayName}" : "無法向 {displayName} 傳送通告",
    "Permissions granted to {displayName}" : "已將權限授予{displayName}",
    "Could not modify permissions for {displayName}" : "無法更改 {displayName} 的權限",
    "Permissions removed for {displayName}" : "移除了 {displayName} 的權限",
    "Permissions set to default for {displayName}" : "{displayName} 的權限設置為默認值",
    "Phone number could not be hung up" : "無法掛斷電話",
    "Phone number could not be put on hold" : "無法暫停電話通話",
    "Phone number could not be muted" : "無法將電話靜音",
    "Phone number could not be unmuted" : "無法取消電話靜音",
    "DTMF message could not be sent" : "無法傳送 DTMF 訊息",
    "Phone number copied to clipboard" : "電話號碼已複製到剪貼板",
    "Phone number could not be copied" : "無法複製電話號碼",
    "in the lobby" : "在等候室中",
    "Dial out phone" : "撥出電話",
    "Hang up phone" : "掛斷電話",
    "Move back to lobby" : "移回等候室",
    "Move to conversation" : "移至對話",
    "Dial-in PIN" : "撥入 PIN",
    "Demote from moderator" : "從主持人降級",
    "Promote to moderator" : "晉升為主持人",
    "Resend invitation" : "重新傳送邀請",
    "Send call notification" : "傳送通話通告",
    "Dial out phone number" : "撥出電話號碼",
    "Resume call for phone number" : "恢復電話號碼的通話",
    "Put phone number on hold" : "保留電話號碼",
    "Unmute phone number" : "取消電話號碼靜音",
    "Mute phone number" : "將電話號碼靜音",
    "Copy phone number" : "複製電話號碼",
    "Reset custom permissions" : "重設自訂權限",
    "Grant all permissions" : "授予所有權限",
    "Remove all permissions" : "移除所有權限",
    "Also ban from this conversation" : "同時從此對話中封禁",
    "Internal note (reason to ban)" : "內部備註（封禁原因）",
    "Remove" : "移除",
    "Permissions modified for {displayName}" : "更改了 {displayName} 的權限",
    "Add users, groups or teams" : "添加用戶，群組和團隊",
    "Add users or groups" : "增加用戶或者群組",
    "Add users or teams" : "添加用戶或團隊",
    "Add users" : "新增用戶",
    "Add groups or teams" : "添加群組或團隊",
    "Add groups" : "新增群組",
    "Add teams" : "添加團隊",
    "Add other sources" : "添加其他來源",
    "Add emails" : "新增電郵",
    "Integrations" : "整合",
    "Add federated users" : "添加 federated 用戶",
    "Searching …" : "正在搜尋……",
    "Search for more users" : "搜尋更多用戶",
    "You can search or add participants via name, email, or Federated Cloud ID" : "您可以透過名稱、電郵地址或雲端聯盟 ID 搜尋或新增參與者",
    "Search or add participants" : "搜尋或添加參與者",
    "Invitation was sent to {actorId}" : "邀請已傳送到 {actorId}",
    "An error occurred while adding the participants" : "添加參與者時發生了錯誤",
    "A new group conversation with selected participant will be created" : "將會建立包含選定參與者的新群組對話",
    "Participants" : "參與者",
    "Pinned by a deleted user" : "由已刪除的用戶置頂",
    "Participants ({count})" : "參與者 ({count})",
    "Open chat" : "開啟聊天",
    "You have new unread messages in the chat." : "您在聊天中有新的未讀消息。",
    "You have been mentioned in the chat." : "您已在聊天中被提及。",
    "Search messages" : "搜尋訊息",
    "Chat" : "聊天",
    "Details" : "細節",
    "Shared items" : "分享項目",
    "Search in {name}" : "在 {name} 中搜尋",
    "Threads in {name}" : "在 {name} 中的討論串",
    "{actor} in {conversation}" : "{conversation} 中的 {actor}",
    "Search messages …" : "搜尋訊息 ...",
    "Search options" : "搜尋選項",
    "From User" : "來自用戶",
    "Since" : "自",
    "Until" : "直至",
    "No results found" : "未找到結果",
    "Load more results" : "正在載入更多結果",
    "Recent threads" : "最近的討論串",
    "Projects" : "專案項目",
    "No shared items" : "沒有已分享的項目",
    "Thread notifications" : "討論串通知",
    "Thread actions" : "討論串動作",
    "{actor}: {lastMessage}" : "{actor}：{lastMessage}",
    "Link to a conversation" : "連結對話",
    "No open conversations found" : "沒有找到公開對話",
    "Either there are no open conversations or you joined all of them." : "要不然就是沒有公開的對話，要不然就是你已經參與了所有的對話。",
    "Check spelling or use complete words." : "檢查拼寫或使用完整的單詞。",
    "Search conversations or users" : "搜尋對話或用戶",
    "Select conversation" : "選擇對話",
    "Number length is not valid" : "號碼長度無效",
    "Region code is not valid" : "區碼無效",
    "Number length is too short" : "號碼長度太短",
    "Number length is too long" : "號碼長度太長",
    "Number is not valid" : "號碼無效",
    "Phone numbers" : "電話號碼",
    "Display name: {name}" : "顯示名稱：{name}",
    "Edit display name" : "編輯顯示名稱",
    "Display name (required)" : "顯示名稱（必填）",
    "Save name" : "保存名字",
    "I picked message bubbles" : "已選擇訊息氣泡",
    "I picked the list style" : "我挑選了清單樣式",
    "Error while setting personal setting" : "設置您的個人設置時發生錯誤",
    "Error while saving sounds setting" : "儲存聲音設置時發生錯誤",
    "Compact conversations list" : "簡潔對話清單",
    "Chat appearance" : "聊天外觀",
    "Messages list" : "訊息清單",
    "Message bubbles" : "訊息氣泡",
    "Play sounds when participants join or leave a call" : "參與者加入或離開通話時播放聲音",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "由於製造商的技術限制，目前在 iPhone 與 iPad 上無法使用",
    "Notification settings" : "通告設定",
    "Sounds for chat and call notifications" : "聊天與通話通知的音效",
    "Invalid language ({languageId})" : "無效的語言（{languageId}）",
    "Default language" : "預設語言",
    "Default language ({languageName})" : "預設語言（{languageName}）",
    "Error when trying to load the available live translation languages" : "載入可用的即時翻譯語言時發生錯誤",
    "Error when trying to set live translation language" : "設定即時翻譯語言時發生錯誤",
    "Set language used to show the transcriptions" : "設定顯示轉錄內容所使用的語言",
    "Select location for attachments" : "選擇附件的位置",
    "Error while setting attachment folder" : "設置附件資料夾時出錯",
    "Error while setting read status privacy" : "設置讀取狀態私隱時出錯",
    "Error while setting typing status privacy" : "設置打字狀態私隱時出錯",
    "Error while setting default media state" : "設定預設媒體狀態時發生錯誤",
    "Turn camera and microphone off by default" : "預設關閉相機與麥克風",
    "Blur camera background by default" : "預設模糊相機背景",
    "Skip device preview before joining a call" : "略過加入通話前的裝置預覽",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "加入時將關閉相機。如需錄影同意，則會一直顯示。",
    "Appearance & Sounds" : "外觀與音效",
    "Privacy" : "私隱",
    "Send read receipts" : "傳送讀取回條",
    "When off, all read statuses will be hidden" : "關閉時，所有讀取狀態都會被隱藏",
    "Share typing status" : "分享輸入狀態",
    "When off, all typing indicators will be hidden" : "關閉時，所有輸入指示器都會被隱藏",
    "Attachments folder" : "附件資料夾",
    "Toggle full screen" : "切換全螢幕",
    "Return to Home screen" : "回到主畫面",
    "Search" : "搜尋",
    "Shortcuts while in a chat" : "聊天中的捷徑",
    "Focus the chat input" : "關注聊天輸入字段",
    "Unfocus the chat input to use shortcuts" : "取消對聊天輸入字段的關注以使用快捷方式",
    "Edit your last message" : "編輯您最新的訊息",
    "Shortcuts while in a call" : "通話中的快捷方式",
    "Camera on and off" : "開啟和關閉相機",
    "Microphone on and off" : "開啟和關閉麥克風",
    "Raise or lower hand" : "舉或放下手",
    "Push to talk or push to mute" : "一鍵通話或靜音",
    "Zoom-in / zoom-out a screen share" : "放大/縮小螢幕分享",
    "Mouse wheel" : "滑鼠滾輪",
    "Start call silently" : "安靜地開始通話",
    "Start call" : "開始通話",
    "End call" : "結束通話",
    "The server was updated, you cannot start or join a call." : "伺服器已更新，您無法開始或加入通話。",
    "This call has just ended" : "此通話剛結束",
    "You will be able to join the call only after a moderator starts it." : "只有主持人發起通話後，您才能加入該通話。",
    "End call for everyone" : "為所有人結束通話",
    "Starting the recording" : "開始錄製",
    "Recording" : "錄製",
    "The call has been running for one hour." : "請注意，通話已經持續一個小時了。",
    "Cancel recording start" : "取消錄製開始",
    "Stop recording" : "停止錄音",
    "Send a reaction" : "傳送反應",
    "React with {reaction}" : "使用 {reaction} 做出反應",
    "All tasks done!" : "所有任務完成!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} / %n 任務"],
    "Add participants to this call" : "新增參與者至此通話",
    "_%n participant in call_::_%n participants in call_" : ["通話中有 %n 位參與者"],
    "Scheduled messages" : "預先安排好的訊息",
    "You are not allowed to enable screensharing" : "你無權啟用啟用螢幕分享",
    "No screensharing" : "沒有螢幕分享",
    "Screensharing options" : "螢幕分享選項",
    "Enable screensharing" : "啟用螢幕分享",
    "Bad sent video and screen quality." : "發送的視像和螢幕質量不佳。",
    "Bad sent screen quality." : "發送的螢幕質量不佳。",
    "Bad sent video quality." : "發送的視像質量不佳。",
    "Bad sent audio, video and screen quality." : "發送的音頻，視像和螢幕質量不佳。",
    "Bad sent audio and screen quality." : "發送的音頻和螢幕質量不佳。",
    "Bad sent audio and video quality." : "發送的音頻和視像質量不佳。",
    "Bad sent audio quality." : "發送的音頻質量不佳。",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "您的互聯網連接或電腦正忙，其他參與者可能無法看到您的螢幕。 為了改善這種情況，嘗試在進行螢幕共享時禁用背景模糊或視像。",
    "Disable background blur" : "禁用背景模糊",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "您的 Internet 連接或電腦繁忙，其他參與者可能看不到您的螢幕。為了改善這種情況，請嘗試在進行螢幕共享時禁用視像。",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "您的 Internet 連接或電腦繁忙，其他參與者可能看不到您的螢幕。",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "您的 Internet 連接或電腦繁忙，其他參與者可能看不到您。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "您的互聯網連接或電腦正忙，其他參與者可能無法理解和看到您。 為了改善這種情況，嘗試在進行螢幕共享時禁用背景模糊或視像。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "您的 Internet 連接或電腦繁忙，其他參與者可能無法理解和看到您。為了改善這種情況，請嘗試在執行螢幕共享時禁用視像。",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "您的 Internet 連接或電腦繁忙，其他參與者可能無法理解和看到您的螢幕。為了改善這種情況，請嘗試停用螢幕共享。",
    "Disable screenshare" : "停用螢幕共享",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "您的互聯網連接或電腦正忙，其他參與者可能無法理解和看到您。 為了改善這種情況，嘗試禁用背景模糊或視像。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "您的 Internet 連接或電腦繁忙，其他參與者可能無法理解和看到您。為了改善這種情況，請嘗試停用您的視像。",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "您的 Internet 連接或電腦繁忙，其他參與者可能聽不到您。",
    "Screen sharing is not supported by your browser." : "您的瀏覽器不支持螢幕共享。",
    "Screen sharing requires the page to be loaded through HTTPS." : "螢幕共享要求頁面通過HTTPS加載。",
    "Screensharing requires the page to be loaded through HTTPS." : "螢幕共享要求頁面通過HTTPS加載。",
    "An error occurred while starting screensharing." : "開始螢幕共享時發生錯誤。",
    "Select virtual background" : "選擇虛擬背景",
    "Show your screen" : "顯示您的螢幕",
    "Stop screensharing" : "停止螢幕分享",
    "Mute others" : "使其他人靜音",
    "Start recording" : "開始錄音",
    "Set up breakout rooms" : "設置分組討論室",
    "Download attendance list" : "下載出勤名單",
    "Open Calendar" : "打開日曆",
    "Remove participant {name}" : "移除參與者 {name}",
    "Would you like to delete this conversation?" : "您想要刪除此對話嗎？",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["此對話在閒置 %n 天後將會自動為所有人刪除"],
    "Are you sure you want to delete this conversation?" : "您確定您想要刪除此對話嗎？",
    "Delete now" : "立刻刪除",
    "Keep" : "保留",
    "Open dialpad" : "開啟撥號鍵盤",
    "Select a region" : "選擇地區",
    "Local time: {time}" : "本地時間︰{time}",
    "Scheduled {datetime}" : "預定於 {datetime}",
    "Scheduled for {datetime}" : "預定於 {datetime}",
    "Search …" : "搜尋 …",
    "Message without mention" : "沒有 @提及的訊息",
    "Mention myself" : "提及自己",
    "Mention everyone" : "提及所有人",
    "Select a conversation" : "選取對話",
    "Select a mode" : "選取模式",
    "You do not have permissions to access this conversation." : "您無權存取此對話。",
    "Join a different conversation or start a new one." : "加入不同的對話或開始新的對話​​。",
    "The conversation does not exist" : "對話不存在",
    "Join a conversation or start a new one!" : "加入或者開一個新的對話",
    "Duplicate session" : "重複對話",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "此對話已在另一個分頁開啟。目前的伺服器版本不支援同一個對話同時在多個分頁開啟。",
    "Creating and joining a conversation with \"{userid}\"" : "使用「{userid}」建立並加入對話",
    "Join a conversation or start a new one" : "加入或者開一個新的對話",
    "Error while joining the conversation" : "加入對話時發生錯誤",
    "Another user" : "另一個用戶",
    "Hey! Are you using the list style or message bubbles?" : "嘿！你用的是清單樣式還是訊息泡泡樣式呢？",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud 用戶",
    "User password" : "用戶密碼",
    "Talk conversation" : "Talk 對話",
    "Skip TLS verification" : "跳過 TLS 驗證",
    "Matrix server URL" : "Matrix 伺服器 URL",
    "User" : "用戶",
    "Matrix channel" : "Matrix 頻道",
    "Mattermost server URL" : "Mattermost 伺服器 URL",
    "Mattermost user" : "Mattermost 用戶",
    "Team name" : "團隊名稱",
    "Channel name" : "頻道名稱",
    "Rocket.Chat server URL" : "Rocket。Chat 伺服器 URL",
    "User name or email address" : "用戶名稱或電郵地址",
    "Rocket.Chat channel" : "Rocket。Chat 頻道",
    "Zulip server URL" : "Zulip 伺服器 URL",
    "Bot user name" : "Bot 用戶名稱",
    "Bot API key" : "Bot API 密鑰",
    "Zulip channel" : "Zulip 頻道",
    "API token" : "API 權杖",
    "Slack channel" : "Slack 頻道",
    "Server ID or name" : "伺服器 ID 或名稱",
    "Channel ID (prefixed with \"ID:\") or name" : "頻道 ID（前綴為「ID:」）或名稱",
    "Channel" : "頻道",
    "Login" : "登入",
    "Chat ID" : "聊天 ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC 伺服器 URL（e.g. chat.freenode.net:6667）",
    "Nickname" : "暱稱",
    "Connection password" : "連線密碼",
    "IRC channel" : "IRC 頻道",
    "Channel password" : "頻道密碼",
    "NickServ nickname" : "NickServ 暱稱",
    "NickServ password" : "NickServ 密碼",
    "Use TLS" : "Use TLS",
    "Use SASL" : "使用 SASL",
    "Tenant ID" : "租戶 ID",
    "Client ID" : "客戶端ID",
    "Team ID" : "團隊 ID",
    "Thread ID" : "帖子 ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber 伺服器 URL",
    "MUC server URL" : "MUC 伺服器 URL",
    "Jabber ID" : "Jabber ID",
    "Pinned messages" : "置頂訊息",
    "Media" : "多媒體",
    "Polls" : "調查",
    "Deck cards" : "看板卡片",
    "Voice messages" : "音頻留言",
    "Locations" : "地點",
    "Call recordings" : "通話錄音",
    "Audio" : "音頻",
    "Show all pinned messages" : "顯示所有置頂訊息",
    "Show all media" : "顯示所有媒體",
    "Show all files" : "顯示所有檔案",
    "Show all polls" : "顯示所有民意調查",
    "Show all deck cards" : "顯示所有卡片",
    "Show all voice messages" : "顯示所有話音短訊",
    "Show all locations" : "顯示所有位置",
    "Show all call recordings" : "顯示所有通話錄音",
    "Show all audio" : "顯示所有音頻",
    "Show all other" : "顯示所有其他",
    "Follow conversation settings" : "跟隨對話設定",
    "Group" : "群組",
    "Team" : "團隊",
    "You reconnected to the call" : "您已重新連線至通話",
    "{actor} reconnected to the call" : "{actor} 已重新連線至通話",
    "You added {user0} and {user1}" : "您添加了 {user0} 與 {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["您添加了 {user0}、{user1} 與 %n 個其他參與者"],
    "An administrator added you and {user0}" : "管理員添加了您與 {user0}",
    "{actor} added you and {user0}" : "{actor} 添加了您與 {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["管理員添加了您、{user0} 與 %n 個其他參與者"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} 添加了您、{user0} 與 %n 個其他參與者"],
    "An administrator added {user0} and {user1}" : "管理員添加了 {user0} 與 {user1}",
    "{actor} added {user0} and {user1}" : "{actor} 添加了 {user0} 與 {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["管理員添加了 {user0}、{user1} 與 %n 個其他參與者"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} 添加了 {user0}、{user1} 與 %n 個其他參與者"],
    "You removed {user0} and {user1}" : "您移除了 {user0} 與 {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["您移除了 {user0}、{user1} 與 %n 個其他參與者"],
    "An administrator removed you and {user0}" : "管理員移除了您與 {user0}",
    "{actor} removed you and {user0}" : "{actor} 移除了您與 {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["管理員移除了您、{user0} 與 %n 個其他參與者"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} 移除了您、{user0} 與 %n 個其他參與者"],
    "An administrator removed {user0} and {user1}" : "管理員移除了 {user0} 與 {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} 移除了 {user0} 與 {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["管理員移除了 {user0}、{user1} 與 %n 個其他參與者"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} 移除了 {user0}、{user1} 與 %n 個其他參與者"],
    "You and {user0} joined the call" : "您與 {user0} 已加入通話",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["您、{user0} 及 %n 個其他參與者加入了通話"],
    "{user0} and {user1} joined the call" : "{user0} 與 {user1} 已加入通話",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}、{user1} 及 %n 個其他參與者已加入通話"],
    "You and {user0} left the call" : "您與 {user0} 已離開通話",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["您、{user0} 及 %n 個其他參與者已離開通話"],
    "{user0} and {user1} left the call" : "{user0} 與 {user1} 已離開通話",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}、{user1} 及 %n 個其他參與者已離開通話"],
    "You promoted {user0} and {user1} to moderators" : "您已將 {user0} 與 {user1} 晉升為主持人",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["您已將 {user0}、{user1} 與 %n 個其他參與者升級為主持人"],
    "An administrator promoted you and {user0} to moderators" : "管理員已將您與 {user0} 升級為主持人",
    "{actor} promoted you and {user0} to moderators" : "{actor} 將您與 {user} 升級為主持人",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["管理員已將您、{user0} 與 %n 個其他參與者升級為主持人"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} 已將您、{user0} 與 %n 個其他參與者升級為主持人"],
    "An administrator promoted {user0} and {user1} to moderators" : "管理員已將 {user0} 與 {user1} 升級為主持人",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} 已將 {user0} 與 {user1} 晉升為主持人",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["管理員已將 {user0}、{user1} 與 %n 個其他參與者升級為主持人"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} 已將 {user0}、{user1} 與 %n 個其他參與者升級為主持人"],
    "You demoted {user0} and {user1} from moderators" : "您已將 {user0} 與 {user1} 由主持人降級",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["您已將 {user0}、{user1} 與 %n 個其他參與者由主持人降級"],
    "An administrator demoted you and {user0} from moderators" : "管理員已將您與 {user0} 由主持人降級",
    "{actor} demoted you and {user0} from moderators" : "{actor} 將您與 {user} 由主持人降級",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["管理員已將您、{user0} 與 %n 個其他參與者由主持人降級"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} 已將您、{user0} 與 %n 個其他參與者由主持人降級"],
    "An administrator demoted {user0} and {user1} from moderators" : "管理員已將 {user0} 與 {user1} 由主持人降級",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} 已將 {user0} 與 {user1} 由主持人降級",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["管理員已將 {user0}、{user1} 與 %n 個其他參與者由主持人降級"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} 已將 {user0}、{user1} 與 %n 個其他參與者由主持人降級"],
    "You:" : "您：",
    "You: {lastMessage}" : "您：{lastMessage}",
    "{actor}:" : "{actor}：",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}，{absoluteDate}",
    "The server was updated." : "伺服器已更新。",
    "(edited by you)" : "（由您編輯）",
    "(edited by a deleted user)" : "(已刪除的用戶編輯)",
    "(edited by {moderator})" : "（由 {moderator} 編輯）",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "您正在嘗試加入對話，而在另一個窗口或裝置中擁有活動會話。Nextcloud Talk 目前不支持此功能。你想做什麼？",
    "Leave this page" : "離開此頁面",
    "Join here" : "在這裡加入",
    "Deck card has been posted to {conversation}" : "Deck 卡片已發佈至 {conversation}",
    "An error occurred while posting deck card to conversation" : "將卡片發佈到對話時發生錯誤",
    "Post to a conversation" : "發佈到對話",
    "Post to conversation" : "發佈到對話",
    "The recording failed. Please contact your administrator." : "錄製失敗。請聯絡管理員。",
    "Location has been posted to {conversation}" : "位置已發佈至 {conversation}",
    "An error occurred while posting location to conversation" : "將位置發佈到對話時發生錯誤。",
    "Share to a conversation" : "分享到對話",
    "Share to conversation" : "分享到對話",
    "In conversation" : "在對話中",
    "Search in conversation: {conversation}" : "在對話中搜尋：{conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "目前由於防止暴力攻擊保護，您的請求受到限制。",
    "Error while clearing conversation history" : "清除對話記錄時出錯",
    "Error occurred while allowing guests" : "允許訪客時發生錯誤",
    "Error occurred while disallowing guests" : "禁止訪客時發生錯誤",
    "Error occurred when restricting the conversation to moderator" : "將對話限制為主持人時發生錯誤",
    "Error occurred when opening the conversation to everyone" : "向所有人打開對話時發生錯誤",
    "Conversation password has been saved" : "對話密碼已被保存",
    "Conversation password has been removed" : "對話密碼已被刪除",
    "Error occurred while saving conversation password" : "保存對話密碼時發生錯誤",
    "Call recording is starting." : "通話錄音開始。",
    "Call recording stopped while starting." : "通話錄音在開始時停止。",
    "Call recording stopped. You will be notified once the recording is available." : "通話錄音已停止。 一旦錄音可用，您將收到通知。",
    "Conversation picture set" : "對話圖片設定",
    "Conversation picture deleted" : "對話圖片已刪除",
    "Could not delete the conversation picture" : "無法刪除對話圖片",
    "Could not remove the automatic expiration" : "無法移除自動過期",
    "Could not post message: {errorMessage}" : "無法發佈訊息：{errorMessage}",
    "Participant is banned successfully" : "成功封禁了參與者",
    "Error while banning the participant" : "封禁參與者時發生錯誤。",
    "An error occurred while fetching the participants" : "擷取參與者時發生錯誤",
    "Could not send invitation to {actorId}" : "向 {actorId} 傳送邀請時發生錯誤",
    "Invitations sent" : "邀請已傳送",
    "Error occurred when sending invitations" : "發送邀請時發生了錯誤",
    "Failed to join the conversation." : "無法加入對話。",
    "An error occurred while creating breakout rooms" : "建立分組討論室時發生了錯誤",
    "An error occurred while re-ordering the attendees" : "重新排序與會者時出錯",
    "An error occurred while deleting breakout rooms" : "刪除分組討論室時發生了錯誤",
    "An error occurred while starting breakout rooms" : "開始分組討論室時發生錯誤。",
    "An error occurred while stopping breakout rooms" : "停止分組討論室時發生錯誤。",
    "An error occurred while sending a message to the breakout rooms" : "向分組討論室傳送訊息時發生了錯誤",
    "An error occurred while requesting assistance" : "請求協助時出錯",
    "An error occurred while resetting the request for assistance" : "重置協助請求時出錯",
    "An error occurred while joining breakout room" : "加入分組討論室時發生錯誤。",
    "Failed to rename the thread" : "重新命名討論串失敗",
    "Error fetching upcoming events" : "擷取即將舉行的活動時發生錯誤",
    "Error fetching upcoming reminders" : "擷取即將舉行的提醒時發生錯誤",
    "An error occurred while accepting an invitation" : "接受邀請時發生錯誤",
    "An error occurred while rejecting an invitation" : "拒絕邀請時發生錯誤",
    "{guest} (guest)" : "{guest}（訪客）",
    "Poll draft has been saved" : "民意調查草稿已保存",
    "An error occurred while saving the draft" : "儲存草稿時發生了錯誤",
    "An error occurred while submitting your vote" : "遞交您的投票時發生錯誤。",
    "An error occurred while ending the poll" : "結束投票時出錯",
    "An error occurred while deleting the poll draft" : "刪除任務時發生了錯誤",
    "Poll \"{name}\" was created by {user}. Click to vote" : "投票「{name}」是由 {user} 建立的。點擊投票",
    "Failed to add reaction" : "添加反應失敗",
    "Failed to remove reaction" : "移除反應失敗",
    "The server is in maintenance mode." : "伺服器正處於維護模式。",
    "Federated server was updated." : "聯合伺服器已更新。",
    "Error while uploading file \"{fileName}\"" : "上傳檔案時發生錯誤 \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "空間不足，不能上傳檔案 \"{fileName}\"",
    "You are not allowed to share files" : "你無權分享檔案",
    "Error while sharing file" : "分享檔案時發生錯誤",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk 不完全支持您使用的瀏覽器。請使用最新版本的 Mozilla Firefox，Microsoft Edge，Google Chrome，Opera 或 Apple Safari。",
    "_In %n hour_::_In %n hours_" : ["%n 小時後"],
    "_%n minute _::_%n minutes_" : ["%n 分鐘"],
    "In {hours} and {minutes}" : "{hours} 與 {minutes} 內",
    "_In %n minute_::_In %n minutes_" : ["%n 分鐘後"],
    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
    "Set time for later today" : "設定今天稍後的時間",
    "Tomorrow – {timeLocale}" : "明日 – {timeLocale}",
    "Set time for tomorrow" : "設定明日的時間",
    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
    "Set time for this weekend" : "設定本週末的時間",
    "Next week – {timeLocale}" : "下星期 – {timeLocale}",
    "Set time for next week" : "設定下星期的時間",
    "Message link copied to clipboard" : "訊息連結已複製到剪貼板",
    "Conversation link copied to clipboard" : "對話連結已複製到剪貼板",
    "The link could not be copied" : "連結無法複製",
    "Error while parsing a PROPFIND error" : "解析 PROPFIND 錯誤時發生錯誤",
    "Sending signaling message has failed" : "傳送訊號訊息失敗",
    "Lost connection to signaling server. Trying to reconnect." : "與信令伺服器的連接斷開。嘗試重新連接。",
    "Lost connection to signaling server." : "與信號伺服器的連接已斷開。",
    "Connecting is taking longer than expected …" : "連線時間比預期長⋯⋯",
    "Failed to connect. Retrying …" : "連線失敗，正在重試⋯⋯",
    "Failed to connect. The signaling server may be set up incorrectly" : "連線失敗，訊號伺服器可能設定不正確",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "配置的信令伺服器需要更新才能兼容此版本的 Talk。 請聯絡您的管理員。",
    "Please restart the app." : "請重新啟動應用程式。",
    "Please reload the page." : "請重新整理頁面。",
    "Please try to restart the app." : "請嘗試重新啟動應用程式。",
    "Please try to reload the page." : "請嘗試重新載入頁面。",
    "Do not disturb" : "請勿打擾",
    "Away" : "離開",
    "Microphone {number}" : "米高風 {number}",
    "Camera {number}" : "相機 {number}",
    "Speaker {number}" : "喇叭 {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "您似乎在靜音時說話，請取消靜音以使其他人聽到您的聲音",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "無法與至少一個參與者建立連接。您的處境可能需要安裝 TURN 伺服器。請要求您的管理員按照 {linkstart}本說明書{linkend} 進行設置。",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "此操作花費的時間比預期的長。是否已授予（或拒絕）媒體權限？如果是，請重新啟動瀏覽器，因為音頻和視像均出現故障",
    "Access to microphone & camera is only possible with HTTPS" : "只有使用 HTTPS 才能存取米高風和相機",
    "Please move your setup to HTTPS" : "請將您的設置移至HTTPS",
    "Access to microphone & camera was denied" : "無法存取米高風和相機",
    "WebRTC is not supported in your browser" : "你使用的瀏覽器不支援 WebRTC",
    "Please use a different browser like Firefox or Chrome" : "請使用其他瀏覽器，例如Firefox或Chrome",
    "Error while accessing microphone & camera" : "存取米高風和相機時發生錯誤",
    "%s Talk on your mobile devices" : "%s Talk 在您的流動裝置上",
    "Join conversations at any time, anywhere, on any device." : "隨時隨地在任何裝置上加入對話。",
    "Android app" : "Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "__language_name__" : "正體中文（香港）",
    "Webhook Demo" : "Webhook 示範",
    "Call summary (%s)" : "通話摘要 (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "通話摘要機器人在通話後張貼概述訊息，列出所有參與者並概述任務",
    "Tasks" : "任務",
    "Notes" : "備註",
    "Reports" : "報告",
    "Decisions" : "決定",
    "Agenda" : "議程",
    "Call summary" : "通話摘要",
    "Call summary - {title}" : "通話摘要 - {title}",
    "Talk conversation for event" : "活動 Talk 對話",
    "Client Push is installed, this improves the performance of desktop clients." : "已安裝客戶端推送，這會改善桌面客戶端的效能。",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "尚未安裝 {notify_push}，在使用桌面客戶端時，這可能會導致性能問題。",
    "Next meeting" : "下一個會議",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "從您的日曆安排會議。必須將 Talk 對話設定為位置以在此處顯示",
    "Join conversations from remote Nextcloud servers" : "加入來自遠端 Nextcloud 伺服器的對話",
    "Your default media state has been saved" : "已儲存您的預設媒體狀態",
    "Set reminder for later today" : "設定今天稍後的提醒",
    "Set reminder for tomorrow" : "設定明日的提醒",
    "Set reminder for this weekend" : "設定本週末的提醒",
    "Set reminder for next week" : "設定下星期的提醒",
    "Generate summary" : "產生摘要",
    "Open poll • You voted already" : "公開民意調查・已投票",
    "Open poll • Click to vote" : "公開民意調查 · 點擊投票",
    "Poll • Ended" : "民意調查・已結束",
    "Talk recording from {time} ({conversation})" : "從 {time} 開始的談話錄音（{conversation}）",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["民意調查結果 • %n 票"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["公開民意調查 • %n 票"],
    "Submit vote" : "遞交投票",
    "Your privacy setting has been saved" : "已更新您的私隱設定",
    "Your personal setting has been saved" : "您的個人設置已保存",
    "Failed to save sounds setting" : "聲音設定儲存失敗",
    "Sounds setting saved" : "聲音設置已保存",
    "Always shown if recording consent is required" : "若需取得錄影同意，此提示將一律顯示",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk 已更新，您無法開始或加入通話。",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "您在另一個窗口或裝置中加入了對話。Nextcloud Talk 目前不支持此功能，因此該節，時段已關閉。",
    "Nextcloud Talk was updated." : "Nextcloud 已更新。",
    "Nextcloud is in maintenance mode." : "Nextcloud 處於維護模式。",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Federation 已更新。",
    "Enable live translation" : "啟用即時翻譯",
    "I picked list style" : "已選擇清單樣式",
    "Hey! Are you using Talk in list style or with message bubbles?" : "你目前在 Talk 中使用列表顯示還是訊息氣泡顯示？"
},
"nplurals=1; plural=0;");
